@@ -108,6 +108,7 @@ public class AllWiseAsciiStarTable extends StreamStarTable {
      * @param   schemaUrl  URL for 'schema' table which describes data types
      * @param   nrow   reported number of rows in table, -1 if unknown
      */
+    @SuppressWarnings("this-escape")
     public AllWiseAsciiStarTable( DataSource datsrc, URL schemaUrl,
                                   long nrow )
             throws IOException {
@@ -206,16 +207,16 @@ public class AllWiseAsciiStarTable extends StreamStarTable {
             }
             else if ( "smallint".equals( type ) ) {
                 decoder = SHORT_DECODER;
-                badnum = new Short( Short.MIN_VALUE );
+                badnum = Short.valueOf( Short.MIN_VALUE );
             }
             else if ( "integer".equals( type ) ) {
                 decoder = INT_DECODER;
-                badnum = new Integer( Integer.MIN_VALUE );
+                badnum = Integer.valueOf( Integer.MIN_VALUE );
             }
             else if ( "int8".equals( type )
                    || "serial8".equals( type ) ) {
                 decoder = LONG_DECODER;
-                badnum = new Long( Long.MIN_VALUE );
+                badnum = Long.valueOf( Long.MIN_VALUE );
             }
             else if ( "char".equals( type ) ) {
                 decoder = CHAR_DECODER;
