@@ -27,7 +27,7 @@ public class CheckFilter extends BasicFilter implements ProcessingStep {
         };
     }
 
-    public ProcessingStep createStep( Iterator argIt ) {
+    public ProcessingStep createStep( Iterator<String> argIt ) {
         return this;
     }
 
