@@ -3,16 +3,19 @@ package uk.ac.starlink.ttools.filter;
 import gnu.jel.CompilationException;
 import java.io.Closeable;
 import java.io.IOException;
-import java.util.Arrays;
-import java.util.Comparator;
+import java.util.ArrayList;
+import java.util.Collection;
 import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.function.Supplier;
 import uk.ac.starlink.table.RowPermutedStarTable;
 import uk.ac.starlink.table.StarTable;
 import uk.ac.starlink.table.Tables;
 import uk.ac.starlink.task.TaskException;
 import uk.ac.starlink.ttools.Tokenizer;
+import uk.ac.starlink.ttools.gpl.SortUtils;
 import uk.ac.starlink.ttools.jel.RandomJELEvaluator;
 
 /**
@@ -137,47 +140,41 @@ public class SortFilter extends BasicFilter {
             boolean isParallel = isParallel_ == null
                                ? nrow > PARALLEL_THRESHOLD
                                : isParallel_.booleanValue();
-            Number[] rowMap = new Number[ nrow ];
+            int[] rowMap = new int[ nrow ];
             for ( int i = 0; i < nrow; i++ ) {
-                rowMap[ i ] = Integer.valueOf( i );
+                rowMap[ i ] = i;
             }
-            RowComparator keyComparator;
-            try {
-                keyComparator = new RowComparator( baseTable, keys_, up_,
-                                                   nullsLast_, isParallel );
+            try ( ComparatorManager cmpMgr =
+                      new ComparatorManager( baseTable, keys_,
+                                             up_, nullsLast_ ) ) {
+                if ( isParallel ) {
+                    SortUtils.parallelIntSort( rowMap, cmpMgr::getComparator );
+                }
+                else {
+                    SortUtils.intSort( rowMap, cmpMgr.getComparator() );
+                }
             }
             catch ( CompilationException e ) {
                 throw (IOException) new IOException( "Bad sort key(s)" )
                                    .initCause( e );
             }
-            try {
-                if ( isParallel ) {
-                    Arrays.parallelSort( rowMap, keyComparator );
-                }
-                else {
-                    Arrays.sort( rowMap, keyComparator );
-                }
-            }
             catch ( SortException e ) {
                 throw e.asIOException();
             }
-            finally {
-                keyComparator.close();
-            }
             long[] rmap = new long[ nrow ];
             for ( int i = 0; i < nrow; i++ ) {
-                rmap[ i ] = rowMap[ i ].longValue();
+                rmap[ i ] = rowMap[ i ];
             }
             return new RowPermutedStarTable( baseTable, rmap );
         }
     }
 
     /** 
-     * Comparator which will compare two objects which are Numbers 
+     * IntComparator which will compare two integers
      * representing row indices of a given table.
+     * Instances are not thread-safe.
      */
-    private static class RowComparator
-            implements Comparator<Number>, Closeable {
+    private static class RowComparator implements IntComparator, Closeable {
 
         final int nexpr_;
         final RandomJELEvaluator[] evaluators_;
@@ -187,27 +184,21 @@ public class SortFilter extends BasicFilter {
         /**
          * Constructor.
          *
-         * @param  table  table whose rows are to be examined
-         * @param  keys   array of column identifiers; first is most
-         *                significant for ordering, second next, etc
+         * @param  keyEvaluators  array of evaluators for sort key values;
+         *                        first is most significant for ordering,
+         *                        second next, etc
          * @param   up  true for sorting into ascending order, false for
          *          descending order
          * @param   nullsLast  true if blank values should be considered
          *          last in the collation order, false if they should
          *          be considered first
          */
-        public RowComparator( StarTable table, String[] keys, boolean up,
-                              boolean nullsLast, boolean isParallel )
-                throws CompilationException, IOException {
-            nexpr_ = keys.length;
+        public RowComparator( RandomJELEvaluator[] keyEvaluators, boolean up,
+                              boolean nullsLast ) {
+            evaluators_ = keyEvaluators;
             up_ = up;
             nullsLast_ = nullsLast;
-            evaluators_ = new RandomJELEvaluator[ nexpr_ ];
-            for ( int ie = 0; ie < nexpr_; ie++ ) {
-                evaluators_[ ie ] =
-                    RandomJELEvaluator
-                   .createEvaluator( table, keys[ ie ], isParallel );
-            }
+            nexpr_ = evaluators_.length;
         }
 
         public void close() throws IOException {
@@ -216,9 +207,7 @@ public class SortFilter extends BasicFilter {
             }
         }
 
-        public int compare( Number o1, Number o2 ) {
-            long row1 = o1.longValue();
-            long row2 = o2.longValue();
+        public int compare( int row1, int row2 ) {
             int c = 0;
             for ( int i = 0; i < nexpr_ && c == 0; i++ ) { 
                 RandomJELEvaluator evaluator = evaluators_[ i ];
@@ -264,6 +253,67 @@ public class SortFilter extends BasicFilter {
         }
     }
 
+    /**
+     * Supplier for RowComparators that keeps track of them and will
+     * close them when it is closed.
+     */
+    private static class ComparatorManager implements Closeable {
+
+        final List<Supplier<RandomJELEvaluator>> evaluatorSuppliers_;
+        final boolean up_;
+        final boolean nullsLast_;
+        final Collection<RowComparator> comparators_;
+
+        /**
+         * Constructor.
+         *
+         * @param  table  table
+         * @param  keys   JEL expressions for sort keys, most significant first
+         * @param   up  true for sorting into ascending order, false for
+         *          descending order
+         * @param   nullsLast  true if blank values should be considered
+         *          last in the collation order, false if they should
+         *          be considered first
+         */
+        ComparatorManager( StarTable table, String[] keys, boolean up,
+                           boolean nullsLast )
+                throws CompilationException {
+            up_ = up;
+            nullsLast_ = nullsLast;
+            evaluatorSuppliers_ = new ArrayList<Supplier<RandomJELEvaluator>>();
+            comparators_ = ConcurrentHashMap.newKeySet();
+            for ( String key : keys ) {
+                evaluatorSuppliers_
+               .add( RandomJELEvaluator.createEvaluatorSupplier( table, key ) );
+            }
+        }
+
+        /**
+         * Returns a RowComparator instance.  This instance is not thread-safe.
+         *
+         * @return  comparator
+         */
+        RowComparator getComparator() {
+            RandomJELEvaluator[] evaluators =
+                evaluatorSuppliers_.stream()
+                                   .map( Supplier::get )
+                                   .toArray( n -> new RandomJELEvaluator[ n ] );
+            RowComparator cmp =
+                new RowComparator( evaluators, up_, nullsLast_ );
+            comparators_.add( cmp );
+            return cmp;
+        }
+
+        /**
+         * Closes any comparators that have been dispatched from this object.
+         */
+        public void close() throws IOException {
+            for ( RowComparator cmp : comparators_ ) {
+                cmp.close();
+            }
+        }
+    }
+
     /**
      * Helper class defining private exception type.
      * Used to smuggle a checked exception out of a sort comparison.
