@@ -216,6 +216,7 @@ public class StatsFilter extends BasicFilter {
             String name = argIt.next();
             argIt.remove();
             String lname = name.toLowerCase();
+            double quantile = parseQuantileSpecifier( name );
             if ( lname.equals( "-parallel" ) ) {
                 isParallel = true;
             }
@@ -231,10 +232,8 @@ public class StatsFilter extends BasicFilter {
             else if ( infoMap.containsKey( lname ) ) {
                 infoList.add( infoMap.get( lname ) );
             }
-            else if ( name.matches( "^[qQ]\\.[0-9]+$" ) ) {
-                double quant = Double.parseDouble( name.substring( 1 ) );
-                assert quant >= 0.0 && quant <= 1.0;
-                infoList.add( new QuantileInfo( quant ) );
+            else if ( ! Double.isNaN( quantile ) ) {
+                infoList.add( new QuantileInfo( quantile ) );
             }
             else {
                 List<ValueInfo> docInfoList = new ArrayList<>();
@@ -291,6 +290,27 @@ public class StatsFilter extends BasicFilter {
         };
     }
 
+    /**
+     * Parses a string that represents an arbitrary quantile.
+     * This is of the form Q.xxx, where xxx is the quantile fraction,
+     * so for instance "Q.01" is the first percentile and "Q.4"
+     * is the 40th percentile.
+     *
+     * @param  txt  text which may represent a quantile specifier
+     * @return  value in the range 0..1 giving the quantile level,
+     *          or NaN if it's not a quantile specifier
+     */
+    public static double parseQuantileSpecifier( String txt ) {
+        if ( txt.matches( "^[qQ]\\.[0-9]+$" ) ) {
+            double quant = Double.parseDouble( txt.substring( 1 ) );
+            assert quant >= 0.0 && quant <= 1.0;
+            return quant;
+        }
+        else {
+            return Double.NaN;
+        }
+    }
+
     /**
      * Constructs a MapGroup containing statistical information about 
      * a given table.
@@ -373,39 +393,40 @@ public class StatsFilter extends BasicFilter {
             /* Add statistical quantities to the column's
              * info->values map. */
             Map<ValueInfo,Object> map = group.getMaps().get( icol );
-            map.put( NGOOD_INFO, new Long( count ) );
-            map.put( NBAD_INFO, new Long( tstats.getRowCount() - count ) );
-            map.put( SUM_INFO, new Double( sum1 ) );
+            map.put( NGOOD_INFO, Long.valueOf( count ) );
+            map.put( NBAD_INFO, Long.valueOf( tstats.getRowCount() - count ) );
+            map.put( SUM_INFO, Double.valueOf( sum1 ) );
             if ( isFinite( mean ) ) {
-                map.put( MEAN_INFO, new Float( (float) mean ) );
+                map.put( MEAN_INFO, Float.valueOf( (float) mean ) );
             }
             if ( isFinite( popvar ) ) {
-                map.put( POPSD_INFO, new Float( (float) Math.sqrt( popvar ) ) );
-                map.put( POPVAR_INFO, new Float( (float) popvar ) );
+                map.put( POPSD_INFO,
+                         Float.valueOf( (float) Math.sqrt( popvar ) ) );
+                map.put( POPVAR_INFO, Float.valueOf( (float) popvar ) );
             }
             if ( isFinite( sampvar ) ) {
                 map.put( SAMPSD_INFO,
-                         new Float( (float) Math.sqrt( sampvar ) ) );
-                map.put( SAMPVAR_INFO, new Float( (float) sampvar ) );
+                         Float.valueOf( (float) Math.sqrt( sampvar ) ) );
+                map.put( SAMPVAR_INFO, Float.valueOf( (float) sampvar ) );
             }
             if ( isFinite( skew ) ) {
-                map.put( SKEW_INFO, new Float( (float) skew ) );
+                map.put( SKEW_INFO, Float.valueOf( (float) skew ) );
             }
             if ( isFinite( kurtosis ) ) {
-                map.put( KURT_INFO, new Float( (float) kurtosis ) );
+                map.put( KURT_INFO, Float.valueOf( (float) kurtosis ) );
             }
             if ( min != null ) {
                 map.put( MIN_INFO, min );
-                map.put( MINPOS_INFO, new Long( stats.getMinPos() + 1 ) );
+                map.put( MINPOS_INFO, Long.valueOf( stats.getMinPos() + 1 ) );
             }
             if ( max != null ) {
                 map.put( MAX_INFO, max );
-                map.put( MAXPOS_INFO, new Long( stats.getMaxPos() + 1 ) );
+                map.put( MAXPOS_INFO, Long.valueOf( stats.getMaxPos() + 1 ) );
             }
             if ( doCard ) {
                 int ncard = stats.getCardinality();
                 if ( ncard > 0 ) {
-                    map.put( CARDINALITY_INFO, new Integer( ncard ) );
+                    map.put( CARDINALITY_INFO, Integer.valueOf( ncard ) );
                 }
             }
             Quantiler quantiler = stats.getQuantiler();
@@ -474,7 +495,7 @@ public class StatsFilter extends BasicFilter {
      * Tests whether a value is finite (not infinite or NaN).
      *
      * @param   val  number to test
-     * @return  true iff <tt>val</tt> is finite
+     * @return  true iff <code>val</code> is finite
      */
     private final static boolean isFinite( double val ) {
         return val > - Double.MAX_VALUE
