@@ -14,6 +14,8 @@ package uk.ac.starlink.ttools.func;
  */
 public class Sky {
 
+    private static final double D2R = Math.PI / 180.0;
+
     /**
      * Private constructor prevents instantiation.
      */
@@ -79,6 +81,61 @@ public class Sky {
         return 0.5 * ( lat1 + lat2 );
     }
 
+    /**
+     * Tests whether a given sky position is inside a given ellipse.
+     *
+     * @param   lon0   test point longitude in degrees
+     * @param   lat0   test point latitude in degrees
+     * @param   lonCenter  ellipse center longitude in degrees
+     * @param   latCenter  ellipse center latitude in degrees
+     * @param   rA   ellipse first principal radius in degrees
+     * @param   rB   ellipse second principal radius in degrees
+     * @param   posAng  position angle in degrees from the North pole
+     *                  to the primary axis of the ellipse in the direction
+     *                  of increasing longitude
+     * @return  true iff test point is inside, or on the border of, the ellipse
+     */
+    public static boolean inSkyEllipse( double lon0, double lat0,
+                                        double lonCenter, double latCenter,
+                                        double rA, double rB, double posAng ) {
+
+        /* Return false for invalid inputs. */
+        if ( ! ( lat0 >= -90 && lat0 <= 90 ) ||
+             ! ( latCenter >= -90 && latCenter <= 90 ) ||
+             ! ( rA >= 0 ) ||
+             ! ( rB >= 0 ) ||
+             Double.isNaN( lon0 ) ||
+             Double.isNaN( lonCenter ) ||
+             Double.isNaN( posAng ) ) {
+            return false;
+        }
+
+        /* Deal with easy cases first. */
+        if ( Math.min( rA, rB ) > 180 ) {
+            return true;
+        }
+        double rMax = Math.max( rA, rB );
+        if ( Math.abs( lat0 - latCenter ) > rMax ) {
+            return false;
+        }
+        double dist = skyDistance( lon0, lat0, lonCenter, latCenter );
+        if ( dist > rMax ) {
+            return false;
+        }
+        if ( dist <= Math.min( rA, rB ) ) {
+            return true;
+        }
+
+        /* Otherwise do the full calculation. */
+        double theta =
+              CoordsDegrees.posAngDegrees( lonCenter, latCenter, lon0, lat0 )
+            - posAng;
+        double cosTheta = Math.cos( D2R * theta );
+        double sinTheta = Math.sin( D2R * theta );
+        double rEllipse = rA * rB / Math.hypot( rB * cosTheta, rA * sinTheta );
+        return dist <= rEllipse;
+    }
+
     /**
      * Tests whether a given sky position is inside the polygon defined
      * by a given set of vertices.  The bounding lines of the polygon
