@@ -76,6 +76,8 @@ public class ResourceIcon {
         MODE_ALPHA_FIX = readIcon( "mode-transparent-lock.png" ),
         MODE_AUX = readIcon( "mode-aux.png" ),
         MODE_WEIGHT = readIcon( "mode-weight.png" ),
+        MODE_PAUX = readIcon( "mode-paux.png" ),
+        MODE_PWEIGHT = readIcon( "mode-pweight.png" ),
         MODE_RGB = readIcon( "mode-rgb.png" ),
         DRAG1 = readIcon( "drag1.png" ),
         DRAG2 = readIcon( "drag2.png" ),
