@@ -33,6 +33,7 @@ import uk.ac.starlink.ttools.func.Distances;
 import uk.ac.starlink.ttools.func.Fluxes;
 import uk.ac.starlink.ttools.func.Formats;
 import uk.ac.starlink.ttools.func.Gaia;
+import uk.ac.starlink.ttools.func.Json;
 import uk.ac.starlink.ttools.func.KCorrections;
 import uk.ac.starlink.ttools.func.Lists;
 import uk.ac.starlink.ttools.func.Maths;
@@ -58,6 +59,7 @@ public class JELUtils {
 
     private static List<Class<?>> staticClasses_;
     private static Logger logger_ = Logger.getLogger( "uk.ac.starlink.ttools" );
+    private static final HashMap<String,Class<?>> CAST_MAP = createCastMap();
 
     /** 
      * System property name for adding colon-separated list of 
@@ -99,9 +101,8 @@ public class JELUtils {
                                          Class<?>[] dynamicLib,
                                          DVMap resolver ) {
         Class<?>[] dotClasses = new Class<?>[ 0 ];
-        HashMap<String,Class<?>> cnmap = null;
-        Library lib =
-            new Library( staticLib, dynamicLib, dotClasses, resolver, cnmap );
+        Library lib = new Library( staticLib, dynamicLib, dotClasses, resolver,
+                                   CAST_MAP );
         markStateDependentFunctions( lib, staticLib );
         return lib;
     }
@@ -170,6 +171,7 @@ public class JELUtils {
                 Fluxes.class,
                 Formats.class,
                 Gaia.class,
+                Json.class,
                 KCorrections.class,
                 Lists.class,
                 Maths.class,
@@ -334,8 +336,9 @@ public class JELUtils {
         else {
             String name = expr.replaceAll( "\\s", "" )
                               .replaceAll( "[^A-Za-z0-9]+", "_" );
-            Class<?> exprClazz = getWrapperType( compEx.getTypeC() );
-            info = new DefaultValueInfo( name, exprClazz );
+            Class<?> exprClazz =
+                new Parser( calcExpr, lib ).parse( null ).resType;
+            info = new DefaultValueInfo( name, getWrapperType( exprClazz ) );
             if ( ! name.trim().equals( expr.trim() ) ) {
                 ((DefaultValueInfo) info).setDescription( expr );
             }
@@ -538,4 +541,27 @@ public class JELUtils {
             return clazz;
         }
     }
+
+    /**
+     * This allows to cast to primitive arrays, which otherwise is not
+     * possible.  Unfortunately type names containing square brackets
+     * are not permitted by the syntax.
+     * Since this is so ugly, it's not really documented,
+     * but it's available for runtime casts if really necessary;
+     * e.g. you can write "(doubleArray)arrayFunction(x)".
+     *
+     * @return  cast map for supply to library constructor
+     */
+    private static HashMap<String,Class<?>> createCastMap() {
+        HashMap<String,Class<?>> cnmap = new HashMap<>();
+        cnmap.put( "booleanArray", boolean[].class );
+        cnmap.put( "charArray", char[].class );
+        cnmap.put( "byteArray", byte[].class );
+        cnmap.put( "shortArray", short[].class );
+        cnmap.put( "intArray", int[].class );
+        cnmap.put( "longArray", long[].class );
+        cnmap.put( "floatArray", float[].class );
+        cnmap.put( "doubleArray", double[].class );
+        return cnmap;
+    }
 }
