@@ -3,6 +3,9 @@ package uk.ac.starlink.ttools.plot2.data;
 import java.util.function.Function;
 import uk.ac.starlink.table.DomainMapper;
 import uk.ac.starlink.table.ValueInfo;
+import uk.ac.starlink.ttools.Area;
+import uk.ac.starlink.ttools.AreaDomain;
+import uk.ac.starlink.ttools.AreaMapper;
 import uk.ac.starlink.ttools.plot2.DataGeom;
 import uk.ac.starlink.ttools.plot2.geom.PlaneDataGeom;
 import uk.ac.starlink.ttools.plot2.geom.SkyDataGeom;
