@@ -32,36 +32,49 @@ public abstract class CoordGroup {
     }
 
     /**
-     * Returns the number of data positions per tuple used by this plotter.
+     * Returns the number of basic data positions per tuple.
      * For instance
      * a scatter plot would use 1,
      * a plot linking pairs of positions in the same table would use 2,
      * and an analytic function would use 0.
-     * Each of these is turned into a data space position by use of the
-     * DataGeom presented at layer creation time.
+     * Each of these can be represented by standard positional coordinates
+     * as appropriate for the geometry, and is turned into a
+     * data space position by use of the DataGeom presented
+     * at layer creation time.
      * A position corresponds to a (fixed) number of coordinate values.
      *
-     * @return   number of sets of positional coordinates
+     * @return   number of sets of basic positional coordinates
      */
-    public abstract int getPositionCount();
+    public abstract int getBasicPositionCount();
 
     /*
      * Returns any coordinates used by this plotter additional to the
-     * positional ones.  In fact there is nothing to stop you using
-     * positional coordinates here,
-     * but they will not be treated in the generic way accorded to
-     * those accounted for by {@link #getPositionCount}.
+     * basic positional ones.
      *
-     * @return  non-positional coordinates
+     * @return  coordinates other than basic positional ones
      */
     public abstract Coord[] getExtraCoords();
 
+    /**
+     * Returns a count of the extra coordinates that can
+     * be considered to represent data positions.
+     * These can be turned into positions by the DataGeom presented at
+     * layer creation time, but they are not suitable for representation
+     * by standard positional coordinates.
+     *
+     * <p>These positional coordinates are assumed to come at the
+     * start of the list of extra coordinates.
+     *
+     * @return  number of sets of positional coordinates in the extras
+     */
+    public abstract int getExtraPositionCount();
+
     /**
      * Returns the starting coordinate index in a DataSpec at which
-     * a given one of the positional coordinates represented
+     * a given one of the basic positional coordinates represented
      * by this coord group will appear.
      *
-     * @param  ipos  index of position supplied by this group
+     * @param  ipos  index of basic position supplied by this group
      *               (first position is zero)
      * @param  geom  data geom with which index will be used
      * @return  index of starting coordinate for given position in dataspec
@@ -70,10 +83,10 @@ public abstract class CoordGroup {
 
     /**
      * Returns the coordinate index in a DataSpec at which
-     * a given one of the non-positional coordinates represented
+     * a given one of the extra coordinates represented
      * by this coord group will appear.
      *
-     * @param  iExtra  index of non-positional coordinate
+     * @param  iExtra  index of extra coordinate
      *                 (first extra coord is zero)
      * @param  geom  data geom with which index will be used
      * @return  index of given extra coordinate in dataspec
@@ -107,19 +120,49 @@ public abstract class CoordGroup {
      * @return  new coord group
      */
     public static CoordGroup createSinglePositionCoordGroup() {
-        return new BasicCoordGroup( 1, new Coord[ 0 ] );
+        return new BasicCoordGroup( 1, new Coord[ 0 ], 0 );
     }
 
     /**
-     * Returns a coord group which contains zero or more positions and
-     * zero or more additional ("extra") coordinates.
+     * Returns a coord group which contains zero or more basic positions and
+     * zero or more additional non-positional ("extra") coordinates.
      *
-     * @param  npos  number of positions
+     * @param  nBasicPos  number of basic positional coordinates
      * @param  extras  non-positional coordinates
      * @return  new coord group
      */
-    public static CoordGroup createCoordGroup( int npos, Coord[] extras ) {
-        return new BasicCoordGroup( npos, extras );
+    public static CoordGroup createCoordGroup( int nBasicPos, Coord[] extras ) {
+        return new BasicCoordGroup( nBasicPos, extras, 0 );
+    }
+
+    /**
+     * Returns a coord group with zero or more basic positions and
+     * zero or more extra coordinates, some of which may be positional.
+     *
+     * @param  nBasicPos  number of basic positional coordinates
+     * @param  extras   additional coordinates
+     * @param  nExtraPos  number of extra coordinates which are positional
+     */
+    public static CoordGroup createCoordGroup( int nBasicPos, Coord[] extras,
+                                               int nExtraPos ) {
+        return new BasicCoordGroup( nBasicPos, extras, nExtraPos );
+    }
+
+    /**
+     * Returns a coord group with no basic positional coordinates.
+     *
+     * @param  coords  all coordinates
+     * @param  nExtraPos  number of the extra coordinates which can be
+     *                    considered to represent data positions
+     * @param  rangeCoordFlags  array of flags corresponding to the
+     *         <code>coords</code> array, true for any coord whose change
+     *         should cause a re-range
+     */
+    public static CoordGroup
+            createNoBasicCoordGroup( Coord[] coords, int nExtraPos,
+                                     boolean[] rangeCoordFlags ) {
+        return new ExtraPosCoordGroup( coords, nExtraPos, rangeCoordFlags,
+                                       false );
     }
 
     /**
@@ -134,7 +177,7 @@ public abstract class CoordGroup {
      */
     public static CoordGroup createPartialCoordGroup(
                                  Coord[] coords, boolean[] rangeCoordFlags ) {
-        return new PartialPosCoordGroup( coords, rangeCoordFlags );
+        return new ExtraPosCoordGroup( coords, 0, rangeCoordFlags, true );
     }
 
     /**
@@ -143,7 +186,7 @@ public abstract class CoordGroup {
      * @return  new coord group
      */
     public static CoordGroup createEmptyCoordGroup() {
-        return new BasicCoordGroup( 0, new Coord[ 0 ] );
+        return new BasicCoordGroup( 0, new Coord[ 0 ], 0 );
     }
 
     /**
@@ -161,34 +204,41 @@ public abstract class CoordGroup {
      * CoordGroup implementation with positional and extra coordinates.
      */
     private static class BasicCoordGroup extends CoordGroup {
-        final int npos_;
+        final int nBasicPos_;
         final Coord[] extraCoords_;
+        final int nExtraPos_;
 
         /**
          * Constructor.
          *
-         * @param  npos  number of data positions
+         * @param  nBasicPos  number of basic data positions
          * @param  extraCoords  non-positional coordinates
+         * @param  nExtraPos  number of extra coords that are positional
          */
-        BasicCoordGroup( int npos, Coord[] extraCoords ) {
-            npos_ = npos;
+        BasicCoordGroup( int nBasicPos, Coord[] extraCoords, int nExtraPos ) {
+            nBasicPos_ = nBasicPos;
             extraCoords_ = extraCoords;
+            nExtraPos_ = nExtraPos;
         }
-        public int getPositionCount() {
-            return npos_;
+        public int getBasicPositionCount() {
+            return nBasicPos_;
         }
         public Coord[] getExtraCoords() {
             return extraCoords_;
         }
+        public int getExtraPositionCount() {
+            return nExtraPos_;
+        }
         public int getPosCoordIndex( int ipos, DataGeom geom ) {
             return getPosCoordCount( geom ) * ipos;
         }
         public int getExtraCoordIndex( int iExtra, DataGeom geom ) {
-            return getPosCoordCount( geom ) * npos_ + iExtra;
+            return getPosCoordCount( geom ) * nBasicPos_ + iExtra;
         }
         public int[] getRangeCoordIndices( DataGeom geom ) {
-            int[] ixs = new int[ getPosCoordCount( geom ) * npos_ ];
-            for ( int i = 0; i < ixs.length; i++ ) {
+            int nRange = getPosCoordCount( geom ) * nBasicPos_ + nExtraPos_;
+            int[] ixs = new int[ nRange ];
+            for ( int i = 0; i < nRange; i++ ) {
                 ixs[ i ] = i;
             }
             return ixs;
@@ -201,21 +251,26 @@ public abstract class CoordGroup {
     /**
      * CoordGroup implementation representing a single partial position.
      */
-    private static class PartialPosCoordGroup extends CoordGroup {
+    private static class ExtraPosCoordGroup extends CoordGroup {
         final Coord[] coords_;
+        final int nExtraPos_;
         final int[] rangeCoordIndices_;
+        final boolean isPartial_;
 
         /**
          * Constructor.
          *
-         * @param   coords   all coordinates, starting with those constituting
-         *                   the partial position
+         * @param   coords   all coordinates
+         * @param   nExtraPos  number of coordinates considered positional
          * @param  rangeCoordFlags  array of flags corresponding to the
          *         <code>coords</code> array, true for any coord whose change
          *         should cause a re-range
+         * @param  isPartial  indicates whether positions are partial
          */
-        PartialPosCoordGroup( Coord[] coords, boolean[] rangeCoordFlags ) {
+        ExtraPosCoordGroup( Coord[] coords, int nExtraPos,
+                            boolean[] rangeCoordFlags, boolean isPartial ) {
             coords_ = coords;
+            nExtraPos_ = nExtraPos;
             IntList ilist = new IntList();
             for ( int i = 0; i < coords.length; i++ ) {
                 if ( rangeCoordFlags[ i ] ) {
@@ -223,13 +278,17 @@ public abstract class CoordGroup {
                 }
             }
             rangeCoordIndices_ = ilist.toIntArray();
+            isPartial_ = isPartial;
         }
-        public int getPositionCount() {
+        public int getBasicPositionCount() {
             return 0;
         }
         public Coord[] getExtraCoords() {
             return coords_;
         }
+        public int getExtraPositionCount() {
+            return nExtraPos_;
+        }
         public int getPosCoordIndex( int ipos, DataGeom geom ) {
             return -1;
         }
@@ -240,7 +299,7 @@ public abstract class CoordGroup {
             return rangeCoordIndices_;
         }
         public boolean isSinglePartialPosition() {
-            return true;
+            return isPartial_;
         }
     }
 }
