@@ -2,6 +2,7 @@ package uk.ac.starlink.ttools.plot2.data;
 
 import java.io.IOException;
 import java.util.Iterator;
+import uk.ac.starlink.table.DomainMapper;
 import uk.ac.starlink.table.RowSequence;
 import uk.ac.starlink.table.StarTable;
 import uk.ac.starlink.table.ValueInfo;
@@ -49,18 +50,22 @@ public interface DataSpec {
 
     /**
      * Returns an identifier for the row mask for this object.
+     * Masks with the same identifier must mean the same thing,
+     * and preferably vice versa.
      *
-     * @return   mask identifier, should implement equals sensibly
+     * @return   mask identifier
      */
-    Object getMaskId();
+    String getMaskId();
 
     /**
      * Returns an identifier for one of the the columns produced by this object.
+     * Coords with the same identifier must mean the same thing,
+     * and preferably vice versa.
      *
      * @param  icoord  column index
-     * @return   column identifier, should implement equals sensibly
+     * @return   column identifier
      */
-    Object getCoordId( int icoord );
+    String getCoordId( int icoord );
 
     /**
      * Returns the coord reader that can read the data for one of this
@@ -76,11 +81,24 @@ public interface DataSpec {
      * to provide data for one of this object's output columns.
      *
      * @param  icoord  column index
-     * @return  array of value infos for column data;
+     * @return  array of value infos for column data inputs;
      *          elements may be null if not known
      */
     ValueInfo[] getUserCoordInfos( int icoord );
 
+    /**
+     * Returns the domain mappers to use for the values supplied by the user
+     * to provide data for one of this object's output columns.
+     * These objects define how the input values as supplied by the user
+     * are to be interpreted as the expected input values for this dataspec.
+     * In many cases this mapping is trivial (for instance Y axis coordinate),
+     * but in some (for instance absolute epoch) it may not be.
+     *
+     * @param  icoord  column index
+     * @return   array of DomainMappers for column data inputs
+     */
+    DomainMapper[] getUserCoordMappers( int icoord );
+
     /**
      * Returns an object that can be used to read the mask and coordinate
      * values from a row sequence derived from this object's source table.
