@@ -1,6 +1,8 @@
 package uk.ac.starlink.ttools.plot2.data;
 
+import java.util.function.Function;
 import uk.ac.starlink.table.DomainMapper;
+import uk.ac.starlink.table.ValueInfo;
 
 /**
  * Coord implementation for long values.
@@ -19,14 +21,17 @@ public class LongCoord extends SingleCoord {
      * @param   isRequired  true if this coordinate is required for plotting
      */
     public LongCoord( InputMeta meta, boolean isRequired ) {
-        super( meta, isRequired, Number.class, StorageType.LONG, null );
+        super( meta, isRequired, SimpleDomain.NUMERIC_DOMAIN,
+               StorageType.LONG );
         badval_ = Long.MIN_VALUE;
     }
 
-    public Object inputToStorage( Object[] userValues,
-                                  DomainMapper[] mappers ) {
-        Object c = userValues[ 0 ];
-        return c instanceof Number ? ((Number) c) : badval_;
+    public Function<Object[],Number> inputStorage( ValueInfo[] infos,
+                                                   DomainMapper[] dms ) {
+        return userValues -> {
+            Object c = userValues[ 0 ];
+            return c instanceof Number ? ((Number) c) : badval_;
+        };
     }
 
     /**
