@@ -2,12 +2,12 @@ package uk.ac.starlink.ttools.plot2.geom;
 
 import java.awt.Graphics;
 import java.awt.Graphics2D;
-import java.awt.Insets;
 import java.awt.Rectangle;
 import java.util.ArrayList;
 import java.util.List;
 import uk.ac.starlink.ttools.plot2.Caption;
 import uk.ac.starlink.ttools.plot2.Captioner;
+import uk.ac.starlink.ttools.plot2.Surround;
 
 /**
  * Implementation class containing SkyAxisLabeller implementations.
@@ -37,8 +37,8 @@ public class SkyAxisLabellers {
         );
     }
 
-    /** Labeller implentation that does no drawing. */
-    public static SkyAxisLabeller NONE = new SkyAxisLabeller() {
+    /** Labeller implementation that does no drawing. */
+    public static final SkyAxisLabeller NONE = new SkyAxisLabeller() {
         public String getLabellerName() {
             return "None";
         }
@@ -46,10 +46,11 @@ public class SkyAxisLabellers {
             return "Axes are not labelled";
         }
         public AxisAnnotation createAxisAnnotation( GridLiner gridLiner,
-                                                    Captioner captioner ) {
+                                                    Captioner captioner,
+                                                    SkySys skySys ) {
             return new AxisAnnotation() {
-                public Insets getPadding( boolean withScroll ) {
-                    return new Insets( 0, 0, 0, 0 );
+                public Surround getSurround( boolean withScroll ) {
+                    return new Surround();
                 }
                 public void drawLabels( Graphics g ) {
                 }
@@ -61,7 +62,7 @@ public class SkyAxisLabellers {
      * Basic labeller implementation.  Grid lines are drawn OK,
      * but not much effort is made to position axis labels sensibly.
      */
-    public static SkyAxisLabeller LAME = new SkyAxisLabeller() {
+    public static final SkyAxisLabeller LAME = new SkyAxisLabeller() {
         public String getLabellerName() {
             return "Basic";
         }
@@ -69,10 +70,11 @@ public class SkyAxisLabellers {
             return "Labels are drawn somewhere near the grid line";
         }
         public AxisAnnotation createAxisAnnotation( final GridLiner gridLiner,
-                                                   final Captioner captioner ) {
+                                                    final Captioner captioner,
+                                                    final SkySys skySys ) {
             return new AxisAnnotation() {
-                public Insets getPadding( boolean withScroll ) {
-                    return new Insets( 0, 0, 0, 0 );
+                public Surround getSurround( boolean withScroll ) {
+                    return new Surround();
                 }
                 public void drawLabels( Graphics g ) {
                     Graphics2D g2 = (Graphics2D) g;
@@ -96,59 +98,45 @@ public class SkyAxisLabellers {
     };
 
     /** Labeller implementation that draws labels outside the plot bounds. */
-    public static SkyAxisLabeller EXTERNAL =
-            new TickSkyAxisLabeller( "External",
-                                     "Labels are drawn"
-                                   + " outside the plot bounds" ) {
-        protected SkyTick[] calculateTicks( double[][][] lines,
-                                            Caption[] labels,
-                                            Rectangle plotBounds ) {
-            List<SkyTick> tickList = new ArrayList<SkyTick>();
-            int nl = labels.length;
-            for ( int il = 0; il < nl; il++ ) {
-                SkyTick tick = createExternalTick( labels[ il ], lines[ il ],
-                                                   plotBounds );
-                if ( tick != null ) {
-                    tickList.add( tick );
-                }
-            }
-            return tickList.toArray( new SkyTick[ 0 ] );
-        }
-    };
+    public static final SkyAxisLabeller EXTERNAL =
+        createExternalLabeller( "External",
+                                "Labels are drawn outside the plot bounds",
+                                false );
 
     /** Labeller implementation that draws labels inside the plot bounds. */
-    public static SkyAxisLabeller INTERNAL =
-            new TickSkyAxisLabeller( "Internal",
-                                     "Labels are drawn"
-                                   + " inside the plot bounds" ) {
-        protected SkyTick[] calculateTicks( double[][][] lines,
-                                            Caption[] labels,
-                                            Rectangle plotBounds ) {
-            List<SkyTick> tickList = new ArrayList<SkyTick>();
-            int nl = labels.length;
-            for ( int il = 0; il < nl; il++ ) {
-                SkyTick tick = createInternalTick( labels[ il ], lines[ il ] );
-                if ( tick != null ) {
-                    tickList.add( tick );
-                }
-            }
-            return tickList.toArray( new SkyTick[ 0 ] );
-        }
-    };
+    public static final SkyAxisLabeller INTERNAL =
+        createInternalLabeller( "Internal",
+                                "Labels are drawn inside the plot bounds",
+                                false );
+
+    /** Labeller implementation like EXTERNAL but with sky system labels. */
+    public static final SkyAxisLabeller EXTSYS =
+        createExternalLabeller( "ExternalSys",
+                                "Like <code>" + EXTERNAL.getLabellerName()
+                              + "</code>, but the axes are also labelled "
+                              + "with coordinate system axis names",
+                                true );
+
+    /** Labeller implementation like INTERNAL but with sky system labels. */
+    public static final SkyAxisLabeller INTSYS =
+        createInternalLabeller( "InternalSys",
+                                "Like <code>" + INTERNAL.getLabellerName()
+                              + "</code>, but the axes are also labelled "
+                              + "with coordinate system axis names",
+                                true );
 
     /**
      * Labeller implementation that draws labels outside the plot bounds
      * unless they don't appear, in which case it draws them inside.
      * Doesn't necessarily end up looking as sensible as it sounds.
      */ 
-    public static SkyAxisLabeller HYBRID =
+    public static final SkyAxisLabeller HYBRID =
             new TickSkyAxisLabeller( "Hybrid",
                                      "Grid lines are labelled outside the "
                                    + "plot bounds where possible, "
                                    + "but inside if they would otherwise "
-                                   + "be invisible" ) {
+                                   + "be invisible", false ) {
  
-
         protected SkyTick[] calculateTicks( double[][][] lines,
                                             Caption[] labels,
                                             Rectangle plotBounds ) {
@@ -177,7 +165,7 @@ public class SkyAxisLabellers {
      */
     public static SkyAxisLabeller[] getKnownLabellers() {
         return new SkyAxisLabeller[] {
-            null, EXTERNAL, INTERNAL, LAME, HYBRID, NONE,
+            null, EXTERNAL, INTERNAL, LAME, HYBRID, NONE, EXTSYS, INTSYS,
         };
     }
 
@@ -193,4 +181,63 @@ public class SkyAxisLabellers {
     public static SkyAxisLabeller getAutoLabeller( boolean skyFillsBounds ) {
         return skyFillsBounds ? EXTERNAL : INTERNAL;
     }
+
+    /**
+     * Creates a labeller that draws labels outside the plot bounds.
+     *
+     * @param  name  labeller name
+     * @param  description  labeller description
+     * @param  labelSys  true to add lon/lat coordinate label names
+     * @return  new labeller
+     */
+    private static SkyAxisLabeller createExternalLabeller( String name,
+                                                           String description,
+                                                           boolean labelSys ) {
+        return new TickSkyAxisLabeller( name, description, labelSys ) {
+            protected SkyTick[] calculateTicks( double[][][] lines,
+                                                Caption[] labels,
+                                                Rectangle plotBounds ) {
+                List<SkyTick> tickList = new ArrayList<SkyTick>();
+                int nl = labels.length;
+                for ( int il = 0; il < nl; il++ ) {
+                    SkyTick tick =
+                        createExternalTick( labels[ il ], lines[ il ],
+                                            plotBounds );
+                    if ( tick != null ) {
+                        tickList.add( tick );
+                    }
+                }
+                return tickList.toArray( new SkyTick[ 0 ] );
+            }
+        };
+    }
+
+    /**
+     * Creates a labeller that draws labels inside the plot bounds.
+     *
+     * @param  name  labeller name
+     * @param  description  labeller description
+     * @param  labelSys  true to add lon/lat coordinate label names
+     * @return  new labeller
+     */
+    private static SkyAxisLabeller createInternalLabeller( String name,
+                                                           String description,
+                                                           boolean labelSys ) {
+        return new TickSkyAxisLabeller( name, description, labelSys ) {
+            protected SkyTick[] calculateTicks( double[][][] lines,
+                                                Caption[] labels,
+                                                Rectangle plotBounds ) {
+                List<SkyTick> tickList = new ArrayList<SkyTick>();
+                int nl = labels.length;
+                for ( int il = 0; il < nl; il++ ) {
+                    SkyTick tick =
+                        createInternalTick( labels[ il ], lines[ il ] );
+                    if ( tick != null ) {
+                        tickList.add( tick );
+                    }
+                }
+                return tickList.toArray( new SkyTick[ 0 ] );
+            }
+        };
+    }
 }
