@@ -4,8 +4,10 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
 import uk.ac.starlink.ttools.plot2.DataGeom;
+import uk.ac.starlink.ttools.plot2.GangerFactory;
 import uk.ac.starlink.ttools.plot2.PlotType;
 import uk.ac.starlink.ttools.plot2.Plotter;
+import uk.ac.starlink.ttools.plot2.SingleGangerFactory;
 import uk.ac.starlink.ttools.plot2.SurfaceFactory;
 import uk.ac.starlink.ttools.plot2.layer.AreaForm;
 import uk.ac.starlink.ttools.plot2.layer.CentralForm;
@@ -94,6 +96,11 @@ public class SkyPlotType
         return SURFACE_FACTORY;
     }
 
+    public GangerFactory<SkySurfaceFactory.Profile,SkyAspect>
+            getGangerFactory() {
+        return SingleGangerFactory.instance();
+    }
+
     public PaperTypeSelector getPaperTypeSelector() {
         return PaperTypeSelector.SELECTOR_2D;
     }
