@@ -33,10 +33,6 @@ public abstract class SphereDataGeom implements DataGeom {
         return 3;
     }
 
-    public boolean hasPosition() {
-        return true;
-    }
-
     public String getVariantName() {
         return "Polar";
     }
