@@ -12,6 +12,7 @@ import java.util.stream.Collectors;
 import uk.ac.starlink.ttools.plot2.Anchor;
 import uk.ac.starlink.ttools.plot2.Caption;
 import uk.ac.starlink.ttools.plot2.Captioner;
+import uk.ac.starlink.ttools.plot2.Surround;
 
 /**
  * Partial SkyAxisLabeller implementation that labels axes with positioned
@@ -24,6 +25,7 @@ public abstract class TickSkyAxisLabeller implements SkyAxisLabeller {
 
     private final String name_;
     private final String description_;
+    private final boolean labelSys_;
     public static Anchor X_ANCHOR = Anchor.N;
     public static Anchor Y_ANCHOR = Anchor.E;
 
@@ -32,10 +34,14 @@ public abstract class TickSkyAxisLabeller implements SkyAxisLabeller {
      *
      * @param  name  labeller name
      * @param  description  labeller description
+     * @param  labelSys  labelSys   determines whether the sky system
+     *                              coordinate names are written on the axes
      */
-    public TickSkyAxisLabeller( String name, String description ) {
+    public TickSkyAxisLabeller( String name, String description,
+                                boolean labelSys ) {
         name_ = name;
         description_ = description;
+        labelSys_ = labelSys;
     }
 
     public String getLabellerName() {
@@ -47,7 +53,8 @@ public abstract class TickSkyAxisLabeller implements SkyAxisLabeller {
     }
 
     public AxisAnnotation createAxisAnnotation( GridLiner gridLiner,
-                                                Captioner captioner ) {
+                                                Captioner captioner,
+                                                SkySys skySys ) {
         Caption[] labels = Arrays.stream( gridLiner.getLabels() )
                                  .map( SkyAxisLabellers::labelCaption )
                                  .collect( Collectors.toList() )
@@ -55,8 +62,8 @@ public abstract class TickSkyAxisLabeller implements SkyAxisLabeller {
         SkyTick[] ticks = calculateTicks( gridLiner.getLines(), labels,
                                           gridLiner.getBounds() );
         ticks = removeOverlaps( ticks, captioner );
-        return new TickAxisAnnotation( ticks, gridLiner.getBounds(),
-                                       captioner );
+        return new TickAxisAnnotation( ticks, gridLiner.getBounds(), captioner,
+                                       labelSys_ ? skySys : null );
     }
 
     /**
@@ -148,8 +155,11 @@ public abstract class TickSkyAxisLabeller implements SkyAxisLabeller {
              * return a tick for this position. */
             if ( Math.abs( py - bounds.y - bounds.height ) < 0.5 ) {
                 if ( upness >= 0.5 ) {
-                    return new SkyTick( label, (int) Math.round( px ),
-                                        bounds.y + bounds.height, X_ANCHOR );
+                    int x = (int) Math.round( px );
+                    if ( x >= bounds.x & x < bounds.x + bounds.width ) {
+                        return new SkyTick( label, x, bounds.y + bounds.height,
+                                            X_ANCHOR );
+                    }
                 }
             }
 
@@ -157,8 +167,10 @@ public abstract class TickSkyAxisLabeller implements SkyAxisLabeller {
              * return a tick for this position. */
             if ( Math.abs( px - bounds.x ) < 0.5 ) {
                 if ( upness <= 0.5 ) {
-                    return new SkyTick( label, bounds.x,
-                                        (int) Math.round( py ), Y_ANCHOR );
+                    int y = (int) Math.round( py );
+                    if ( y >= bounds.y && y < bounds.y + bounds.height ) {
+                        return new SkyTick( label, bounds.x, y, Y_ANCHOR );
+                    }
                 }
             }
         }
@@ -240,6 +252,17 @@ public abstract class TickSkyAxisLabeller implements SkyAxisLabeller {
         return new SkyTick( label, px, py, anchor );
     }
 
+    /**
+     * Creates a caption from a text string that may contain spaces.
+     * No attempt is made to handle other potentially problematic characters.
+     *
+     * @param   txt  caption text
+     * @return   caption object
+     */
+    private static Caption textToCaption( String txt ) {
+        return Caption.createCaption( txt, txt.replace( " ", "\\ " ) );
+    }
+
     /**
      * AxisAnnotation implementation that gets its labels from a supplied
      * list of SkyTick objects.
@@ -249,6 +272,11 @@ public abstract class TickSkyAxisLabeller implements SkyAxisLabeller {
         private final SkyTick[] ticks_;
         private final Rectangle plotBounds_;
         private final Captioner captioner_;
+        private final SkySys skySys_;
+        private final Caption lonCaption_;
+        private final Caption latCaption_;
+        private final int hLon_;
+        private final int hLat_;
 
         /**
          * Constructor.
@@ -256,33 +284,102 @@ public abstract class TickSkyAxisLabeller implements SkyAxisLabeller {
          * @param  ticks  tick list
          * @param  plotBounds  plot graphics region
          * @param  captioner  text renderer
+         * @param  skySys  sky system with which to label axes,
+         *                  or null if not labelled
          */
         TickAxisAnnotation( SkyTick[] ticks, Rectangle plotBounds,
-                            Captioner captioner ) {
+                            Captioner captioner, SkySys skySys ) {
             ticks_ = ticks;
             plotBounds_ = plotBounds;
             captioner_ = captioner;
+            skySys_ = skySys;
+            if ( skySys != null ) {
+                lonCaption_ = textToCaption( skySys_.getLongitudeName() );
+                latCaption_ = textToCaption( skySys_.getLatitudeName() );
+                hLon_ = captioner_.getCaptionBounds( lonCaption_ ).height;
+                hLat_ = captioner_.getCaptionBounds( latCaption_ ).height;
+            }
+            else {
+                lonCaption_ = null;
+                latCaption_ = null;
+                hLon_ = 0;
+                hLat_ = 0;
+            }
         }
 
-        public Insets getPadding( boolean withScroll ) {
-            Rectangle bounds = new Rectangle( plotBounds_ );
-            for ( int i = 0; i < ticks_.length; i++ ) {
-                SkyTick tick = ticks_[ i ];
-                if ( withScroll ) {
-                    extendScrollBounds( bounds, tick );
+        public Surround getSurround( boolean withScroll ) {
+            Surround surround = getTickSurround( withScroll );
+            if ( skySys_ != null ) {
+                int lonExtra = hLon_ + hLon_ / 2;
+                surround.bottom.extent += lonExtra;
+                int latExtra = hLat_ + hLat_ / 2;
+                surround.left.extent += latExtra;
+            }
+            return surround;
+        }
+
+        /**
+         * Returns the required space around the edge of the plot bounds
+         * due only to the ticks themselves managed by this annotation.
+         * Additional padding may be added outside this.
+         *
+         * @param  withScroll  true if the padding should be large enough to
+         *                     accommodate labelling requirements if the
+         *                     surface is scrolled
+         * @return  surround space
+         */
+        private Surround getTickSurround( boolean withScroll ) {
+
+            /* If the tickmarks are aligned with the axes, treat this
+             * like a 2d plot.  This will calculate the surround nicely
+             * taking proper account of tick labels that overflow the X/Y
+             * boundaries of the axes etc. */
+            boolean isAllExternal = Arrays.stream( ticks_ )
+                                   .allMatch( t -> t.anchor_ == X_ANCHOR ||
+                                                   t.anchor_ == Y_ANCHOR );
+            if ( isAllExternal ) {
+                Surround surround = new Surround();
+                for ( SkyTick tick : ticks_ ) {
+                    Rectangle tickBox = getTickBounds( tick, withScroll );
+                    boolean isExternal =
+                        surround.addExternalRectangle( plotBounds_, tickBox );
+                    assert isExternal;
                 }
+                return surround;
+            }
+
+            /* Otherwise, the job is more complicated to do properly. */
+            else {
+
+                /* In case of scrolling, don't even attempt it,
+                 * because the usual method of moving the labels to
+                 * both ends of the axis won't work to find out their
+                 * maximum footprint, and it's too hard to do it properly.
+                 * The effect is that internal tick labels may overflow
+                 * the plot bounds sometimes. */
+                if ( withScroll ) {
+                    return new Surround();
+                }
+
+                /* If not scrolling, get the actual position of the tick
+                 * labels and create a simple Surround object that just
+                 * leaves any required space clear round the edges. */
                 else {
-                    extendBounds( bounds, tick );
+                    Rectangle bounds = new Rectangle( plotBounds_ );
+                    for ( SkyTick tick : ticks_ ) {
+                        bounds.add( tick.getCaptionBounds( captioner_ ) );
+                    }
+                    int top = plotBounds_.y - bounds.y;
+                    int left = plotBounds_.x - bounds.x;
+                    int bottom = bounds.y + bounds.height
+                               - plotBounds_.y - plotBounds_.height;
+                    int right = bounds.x + bounds.width
+                              - plotBounds_.x - plotBounds_.width;
+                    assert top >= 0 && left >= 0 && bottom >= 0 && right >= 0;
+                    return Surround
+                          .fromInsets( new Insets( top, left, bottom, right ));
                 }
             }
-            int top = plotBounds_.y - bounds.y;
-            int left = plotBounds_.x - bounds.x;
-            int bottom = bounds.y + bounds.height
-                       - plotBounds_.y - plotBounds_.height;
-            int right = bounds.x + bounds.width
-                      - plotBounds_.x - plotBounds_.width;
-            assert top >= 0 && left >= 0 && bottom >= 0 && right >= 0;
-            return new Insets( top, left, bottom, right );
         }
 
         public void drawLabels( Graphics g ) {
@@ -291,51 +388,60 @@ public abstract class TickSkyAxisLabeller implements SkyAxisLabeller {
                 tick.anchor_.drawCaption( tick.label_, tick.px_, tick.py_,
                                           captioner_, g );
             }
+            if ( skySys_ != null ) {
+                Insets insets = getTickSurround( false ).toInsets();
+                Point pLon =
+                    new Point( plotBounds_.x + plotBounds_.width / 2,
+                               plotBounds_.y + plotBounds_.height
+                             + insets.bottom );
+                Point pLat =
+                    new Point( plotBounds_.x - insets.left - 2 * hLat_,
+                               plotBounds_.y + plotBounds_.height / 2 );
+                Anchor.N.drawCaption( lonCaption_, pLon.x, pLon.y,
+                                      captioner_, g );
+                Anchor.createAngledAnchor( -0.5 * Math.PI, Anchor.N )
+                      .drawCaption( latCaption_, pLat.x, pLat.y,
+                                    captioner_, g );
+            }
         }
 
         /**
-         * Adds the bounds of a tickmark to a rectangle.
+         * Returns the effective bounding rectangle for a tick's annotation.
          *
-         * @param  bounds  bounding rectangle, altered in place
-         * @param  tick  tick mark whose bounds are added to <code>bounds</code>
+         * @param  tick  tick
+         * @param  withScroll  true if the padding should be large enough to
+         *                     accommodate labelling requirements if the
+         *                     surface is scrolled
+         * @return  space on axis to reserve for this tick
          */
-        private void extendBounds( Rectangle bounds, SkyTick tick ) {
-            bounds.add( tick.getCaptionBounds( captioner_ ) );
-        }
-
-        /**
-         * Adds the bounds of a tickmark to a rectangle,
-         * with adjustment for future scrolling.
-         *
-         * @param  bounds  bounding rectangle, altered in place
-         * @param  tick  tick mark whose bounds are added to <code>bounds</code>
-         * @param   Surface#getPlotInsets
-         */
-        private void extendScrollBounds( Rectangle bounds, SkyTick tick ) {
-            Rectangle box = plotBounds_;
-            Anchor anchor = tick.anchor_;
-            final Point[] points;
-            if ( anchor == X_ANCHOR ) {
-                int py = box.y + box.height;
-                points = new Point[] {
-                    new Point( box.x, py ),
-                    new Point( box.x + box.width, py ),
-                };
-            }
-            else if ( anchor == Y_ANCHOR ) {
-                int px = box.x;
-                points = new Point[] {
-                    new Point( px, box.y ),
-                    new Point( px, box.y + box.height ),
-                };
-            }
-            else {
-                points = new Point[ 0 ];
-            }
-            for ( int ip = 0; ip < points.length; ip++ ) {
-                Point p = points[ ip ];
-                bounds.add( tick.getCaptionBoundsAt( p.x, p.y, captioner_ ) );
+        private Rectangle getTickBounds( SkyTick tick, boolean withScroll ) {
+            Rectangle box = tick.getCaptionBounds( captioner_ );
+            if ( withScroll ) {
+                Anchor anchor = tick.anchor_;
+                final Point[] points;
+                if ( anchor == X_ANCHOR ) {
+                    int py = plotBounds_.y + plotBounds_.height;
+                    points = new Point[] {
+                        new Point( plotBounds_.x, py ),
+                        new Point( plotBounds_.x + plotBounds_.width, py ),
+                    };
+                }
+                else if ( anchor == Y_ANCHOR ) {
+                    int px = plotBounds_.x;
+                    points = new Point[] {
+                        new Point( px, plotBounds_.y ),
+                        new Point( px, plotBounds_.y + plotBounds_.height ),
+                    };
+                }
+                else {
+                    points = new Point[ 0 ];
+                }
+                for ( int ip = 0; ip < points.length; ip++ ) {
+                    Point p = points[ ip ];
+                    box.add( tick.getCaptionBoundsAt( p.x, p.y, captioner_ ) );
+                }
             }
+            return box;
         }
     }
 
