@@ -1,6 +1,5 @@
 package uk.ac.starlink.ttools.plot2.layer;
 
-import uk.ac.starlink.ttools.plot2.DataGeom;
 import uk.ac.starlink.ttools.plot2.data.Coord;
 import uk.ac.starlink.ttools.plot2.data.FloatingCoord;
 import uk.ac.starlink.ttools.plot2.data.InputMeta;
@@ -12,7 +11,7 @@ import uk.ac.starlink.ttools.plot2.data.Tuple;
  * @author   Mark Taylor
  * @since    18 Feb 2013
  */
-public class CartesianVectorCoordSet implements MultiPointCoordSet {
+public class CartesianVectorCoordSet implements CartesianMultiPointCoordSet {
 
     private final int ndim_;
     private final FloatingCoord[] componentCoords_;
@@ -53,8 +52,8 @@ public class CartesianVectorCoordSet implements MultiPointCoordSet {
         return 1;
     }
 
-    public boolean readPoints( Tuple tuple, int icol, DataGeom geom,
-                               double[] xy0, double[][] xyExtras ) {
+    public boolean readPoints( Tuple tuple, int icol, double[] xy0,
+                               double[][] xyExtras ) {
         double[] xy1 = xyExtras[ 0 ];
         for ( int idim = 0; idim < ndim_; idim++ ) {
             double delta = componentCoords_[ idim ]
