@@ -68,7 +68,7 @@ public class MarkArrayForm implements ShapeForm {
         icYs_ = 1;
     }
 
-    public int getPositionCount() {
+    public int getBasicPositionCount() {
         return 0;
     }
 
@@ -94,7 +94,12 @@ public class MarkArrayForm implements ShapeForm {
         return new Coord[ 0 ];
     }
 
-    public DataGeom adjustGeom( DataGeom geom ) {
+    public int getExtraPositionCount() {
+        return 0;
+    }
+
+    public DataGeom adjustGeom( DataGeom geom, DataSpec dataSpec,
+                                ShapeStyle style ) {
         return geom;
     }
 
