@@ -17,6 +17,7 @@ import uk.ac.starlink.ttools.plot2.Glyph;
 import uk.ac.starlink.ttools.plot2.Pixer;
 import uk.ac.starlink.ttools.plot2.PlotUtil;
 import uk.ac.starlink.ttools.plot2.PointCloud;
+import uk.ac.starlink.ttools.plot2.ReportMap;
 import uk.ac.starlink.ttools.plot2.Span;
 import uk.ac.starlink.ttools.plot2.SubCloud;
 import uk.ac.starlink.ttools.plot2.Surface;
@@ -73,7 +74,7 @@ public abstract class MarkForm implements ShapeForm {
         icon_ = icon;
     }
 
-    public int getPositionCount() {
+    public int getBasicPositionCount() {
         return npos_;
     }
 
@@ -97,7 +98,12 @@ public abstract class MarkForm implements ShapeForm {
         return new Coord[ 0 ];
     }
 
-    public DataGeom adjustGeom( DataGeom geom ) {
+    public int getExtraPositionCount() {
+        return 0;
+    }
+
+    public DataGeom adjustGeom( DataGeom geom, DataSpec dataSpec,
+                                ShapeStyle style ) {
         return geom;
     }
 
@@ -385,6 +391,10 @@ public abstract class MarkForm implements ShapeForm {
             return ((BinPlan) plan).getBinner().getTotal();
         }
 
+        public ReportMap getReport( Object plan ) {
+            return null;
+        }
+
         /**
          * Convolves a grid of bin counts with a marker shape to produce
          * a grid of values indicating how many pixels would be plotted
