@@ -65,7 +65,7 @@ public class PairLinkForm implements ShapeForm {
         } );
     }
 
-    public int getPositionCount() {
+    public int getBasicPositionCount() {
         return 2;
     }
 
@@ -73,7 +73,12 @@ public class PairLinkForm implements ShapeForm {
         return new Coord[ 0 ];
     }
 
-    public DataGeom adjustGeom( DataGeom geom ) {
+    public int getExtraPositionCount() {
+        return 0;
+    }
+
+    public DataGeom adjustGeom( DataGeom geom, DataSpec dataSpec,
+                                ShapeStyle style ) {
         return geom;
     }
 
