@@ -12,9 +12,10 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import javax.swing.Icon;
+import uk.ac.starlink.ttools.Area;
+import uk.ac.starlink.ttools.cone.CdsHealpixUtil;
 import uk.ac.starlink.ttools.plot2.AuxReader;
 import uk.ac.starlink.ttools.plot2.AuxScale;
-import uk.ac.starlink.ttools.plot2.CdsHealpixUtil;
 import uk.ac.starlink.ttools.plot2.DataGeom;
 import uk.ac.starlink.ttools.plot2.Equality;
 import uk.ac.starlink.ttools.plot2.Glyph;
@@ -24,7 +25,6 @@ import uk.ac.starlink.ttools.plot2.Surface;
 import uk.ac.starlink.ttools.plot2.config.ConfigKey;
 import uk.ac.starlink.ttools.plot2.config.ConfigMeta;
 import uk.ac.starlink.ttools.plot2.config.StyleKeys;
-import uk.ac.starlink.ttools.plot2.data.Area;
 import uk.ac.starlink.ttools.plot2.data.AreaCoord;
 import uk.ac.starlink.ttools.plot2.data.Coord;
 import uk.ac.starlink.ttools.plot2.data.DataSpec;
@@ -1434,18 +1434,15 @@ public class PolygonOutliner extends PixOutliner {
                     radius = Double.isNaN( radius ) ? 1.0 : radius;
                     if ( radius > 0 ) {
                         Area area = areaCoord_.readAreaCoord( tuple, icArea_ );
-                        Area.Type type = area.getType();
-                        if ( type != null ) {
-                            return createSphereAreaVertexData( area, radius );
-                        }
-                        else {
-                            assert false;
-                            return NO_VERTEX_DATA;
+                        if ( area != null ) {
+                            Area.Type type = area.getType();
+                            if ( type != null ) {
+                                return createSphereAreaVertexData( area,
+                                                                   radius );
+                            }
                         }
                     }
-                    else {
-                        return NO_VERTEX_DATA;
-                    }
+                    return NO_VERTEX_DATA;
                 }
                 public int getPosCoordIndex() {
                     return icArea_;
@@ -1548,6 +1545,14 @@ public class PolygonOutliner extends PixOutliner {
                 return toSphere( point[ 0 ], point[ 1 ], radius, dpos )
                      ? createPointVertexData( dpos )
                      : NO_VERTEX_DATA;
+            case MOC:
+                double[] duniqs = area.getDataArray();
+                return new MocVertexData( duniqs, HPX_INTERPOLATE_LEVEL ) {
+                    void copyLonlat( double lonRad, double latRad,
+                                     double[] dpos ) {
+                        CdsHealpixUtil.lonlatToVector( lonRad, latRad, dpos );
+                    }
+                };
             case MULTISHAPE:
                 VertexData[] vds =
                     Arrays
