@@ -56,7 +56,7 @@ public class SizeXyForm implements ShapeForm {
     private SizeXyForm() {
     }
 
-    public int getPositionCount() {
+    public int getBasicPositionCount() {
         return 1;
     }
 
@@ -114,7 +114,12 @@ public class SizeXyForm implements ShapeForm {
         };
     }
 
-    public DataGeom adjustGeom( DataGeom geom ) {
+    public int getExtraPositionCount() {
+        return 0;
+    }
+
+    public DataGeom adjustGeom( DataGeom geom, DataSpec dataSpec,
+                                ShapeStyle style ) {
         return geom;
     }
 
