@@ -7,7 +7,6 @@ import java.awt.Graphics2D;
 import java.awt.Point;
 import java.awt.Rectangle;
 import java.awt.Stroke;
-import java.awt.geom.Point2D;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
@@ -60,7 +59,6 @@ public class Stats1Plotter implements Plotter<Stats1Plotter.StatsStyle> {
     private final FloatingCoord xCoord_;
     private final FloatingCoord weightCoord_;
     private final ConfigKey<Unit> unitKey_;
-    private final SliceDataGeom fitDataGeom_;
     private final CoordGroup fitCoordGrp_;
     private final int icX_;
     private final int icWeight_;
@@ -130,8 +128,6 @@ public class Stats1Plotter implements Plotter<Stats1Plotter.StatsStyle> {
                .createPartialCoordGroup( new Coord[] { xCoord },
                                          new boolean[] { false } );
         }
-        fitDataGeom_ =
-            new SliceDataGeom( new FloatingCoord[] { xCoord_, null }, "X" );
 
         /* For this plot type, coordinate indices are not sensitive to
          * plot-time geom (the CoordGroup has no point positions),
@@ -183,6 +179,7 @@ public class Stats1Plotter implements Plotter<Stats1Plotter.StatsStyle> {
         List<ConfigKey<?>> list = new ArrayList<ConfigKey<?>>();
         list.add( StyleKeys.COLOR );
         list.add( SHOWMEAN_KEY );
+        list.add( StyleKeys.SIDEWAYS );
         list.addAll( Arrays.asList( StyleKeys.getStrokeKeys() ) );
         list.add( StyleKeys.ANTIALIAS );
         if ( unitKey_ != null ) {
@@ -196,6 +193,7 @@ public class Stats1Plotter implements Plotter<Stats1Plotter.StatsStyle> {
     public StatsStyle createStyle( ConfigMap config ) {
         Color color = config.get( StyleKeys.COLOR );
         boolean showmean = Boolean.TRUE.equals( config.get( SHOWMEAN_KEY ) );
+        boolean isY = config.get( StyleKeys.SIDEWAYS ).booleanValue();
         Stroke stroke = StyleKeys.createStroke( config, BasicStroke.CAP_ROUND,
                                                 BasicStroke.JOIN_ROUND );
         boolean antialias = config.get( StyleKeys.ANTIALIAS );
@@ -203,7 +201,7 @@ public class Stats1Plotter implements Plotter<Stats1Plotter.StatsStyle> {
         Unit unit = unitKey_ == null ? Unit.UNIT : config.get( unitKey_ );
         BinSizer sizer = config.get( BINSIZER_KEY );
         return new StatsStyle( color, stroke, antialias, showmean,
-                               norm, unit, sizer );
+                               norm, unit, sizer, isY );
     }
 
     @Override
@@ -214,7 +212,12 @@ public class Stats1Plotter implements Plotter<Stats1Plotter.StatsStyle> {
     public PlotLayer createLayer( final DataGeom geom, final DataSpec dataSpec,
                                   final StatsStyle style ) {
         LayerOpt layerOpt = new LayerOpt( style.getColor(), true );
-        return new AbstractPlotLayer( this, fitDataGeom_, dataSpec,
+        boolean isY = style.isY_;
+        DataGeom fitDataGeom =
+              isY
+            ? new SliceDataGeom( new FloatingCoord[] { null, xCoord_ }, "Y" )
+            : new SliceDataGeom( new FloatingCoord[] { xCoord_, null }, "X" );
+        return new AbstractPlotLayer( this, fitDataGeom, dataSpec,
                                       style, layerOpt ) {
             public Drawing createDrawing( Surface surface,
                                           Map<AuxScale,Span> auxSpans,
@@ -226,19 +229,19 @@ public class Stats1Plotter implements Plotter<Stats1Plotter.StatsStyle> {
             public void extendCoordinateRanges( Range[] ranges,
                                                 boolean[] logFlags,
                                                 DataStore dataStore ) {
-                boolean isLog = logFlags[ 0 ];
+                boolean isLog = logFlags[ isY ? 1 : 0 ];
                 WStats stats = collectStats( isLog, dataSpec, dataStore );
                 StatsPlan plan = new StatsPlan( isLog, stats, dataSpec );
                 double mean = stats.getMean();
                 double sd = stats.getSigma();
-                Range xRange = ranges[ 0 ];
+                Range xRange = ranges[ isY ? 1 : 0 ];
                 xRange.submit( mean - sd * 2 );
                 xRange.submit( mean + sd * 2 );
                 if ( xRange.isFinite() ) {
                     double[] xlims = xRange.getFiniteBounds( isLog );
                     double yhi = plan.getFactor( xlims[ 0 ], xlims[ 1 ],
-                                                 Rounding.DECIMAL, style);
-                    Range yRange = ranges[ 1 ];
+                                                 Rounding.DECIMAL, style );
+                    Range yRange = ranges[ isY ? 0 : 1 ];
                     yRange.submit( 0 );
                     yRange.submit( yhi );
                 }
@@ -312,6 +315,7 @@ public class Stats1Plotter implements Plotter<Stats1Plotter.StatsStyle> {
         final Normalisation norm_;
         final Unit unit_;
         final BinSizer sizer_;
+        final boolean isY_;
 
         /**
          * Constructor.
@@ -324,15 +328,17 @@ public class Stats1Plotter implements Plotter<Stats1Plotter.StatsStyle> {
          * @param  unit   axis scaling unit
          * @param  sizer   histogram equivalent bin sizer,
          *                 may be used in conjunction with norm
+         * @param  isY    if true, plotted sideways
          */
         public StatsStyle( Color color, Stroke stroke, boolean antialias,
                            boolean showmean, Normalisation norm, Unit unit,
-                           BinSizer sizer ) {
+                           BinSizer sizer, boolean isY ) {
             super( color, stroke, antialias );
             showmean_ = showmean;
             norm_ = norm;
             unit_ = unit;
             sizer_ = sizer;
+            isY_ = isY;
         }
 
         @Override
@@ -342,6 +348,7 @@ public class Stats1Plotter implements Plotter<Stats1Plotter.StatsStyle> {
             code = 23 * code + PlotUtil.hashCode( norm_ );
             code = 23 * code + unit_.hashCode();
             code = 23 * code + PlotUtil.hashCode( sizer_ );
+            code = 23 * code + ( isY_ ? 71 : 41 );
             return code;
         }
 
@@ -353,7 +360,8 @@ public class Stats1Plotter implements Plotter<Stats1Plotter.StatsStyle> {
                     && this.showmean_ == other.showmean_
                     && PlotUtil.equals( this.norm_, other.norm_ )
                     && this.unit_.equals( other.unit_ )
-                    && PlotUtil.equals( this.sizer_, other.sizer_ );
+                    && PlotUtil.equals( this.sizer_, other.sizer_ )
+                    && this.isY_ == other.isY_;
             }
             else {
                 return false;
@@ -392,7 +400,7 @@ public class Stats1Plotter implements Plotter<Stats1Plotter.StatsStyle> {
 
         public Object calculatePlan( Object[] knownPlans,
                                      DataStore dataStore ) {
-            final boolean isLog = surface_.getLogFlags()[ 0 ];
+            final boolean isLog = surface_.getLogFlags()[ style_.isY_ ? 1 : 0 ];
 
             /* If one of the known plans matches the one we're about
              * to calculate, just return that. */
@@ -473,39 +481,43 @@ public class Stats1Plotter implements Plotter<Stats1Plotter.StatsStyle> {
         void paintLine( Graphics g, PlanarSurface surface, StatsStyle style,
                         boolean isBitmap ) {
             double factor = getFactor( surface, style );
+            boolean isY = style.isY_;
+            Axis xAxis = surface.getAxes()[ isY ? 1 : 0 ];
+            Axis yAxis = surface.getAxes()[ isY ? 0 : 1 ];
             Graphics2D g2 = (Graphics2D) g;
             Rectangle box = surface.getPlotBounds();
-            int gxlo = box.x - 2;
-            int gxhi = box.x + box.width + 2;
+            int gxlo = xAxis.getGraphicsLimits()[ 0 ] - 2;
+            int gxhi = xAxis.getGraphicsLimits()[ 1 ] + 2;
             int np = gxhi - gxlo;
             LineTracer tracer = style.createLineTracer( g2, box, np, isBitmap );
             Color color = style.getColor();
-            Point2D.Double gpos = new Point2D.Double();
-            double[] dpos = new double[ surface.getDataDimCount() ];
             for ( int ip = 0; ip < np; ip++ ) {
-                double dx =
-                    surface
-                   .graphicsToData( new Point( gxlo + ip, box.y ), null )[ 0 ];
+                double gx = gxlo + ip;
+                double dx = xAxis.graphicsToData( gx );
                 if ( ! Double.isNaN( dx ) ) {
-                    dpos[ 0 ] = dx;
-                    dpos[ 1 ] = factor * gaussian( dx );
-                    if ( surface.dataToGraphics( dpos, false, gpos ) &&
-                         PlotUtil.isPointReal( gpos ) ) {
-                        tracer.addVertex( gpos.x, gpos.y, color );
+                    double dy = factor * gaussian( dx );
+                    double gy = yAxis.dataToGraphics( dy );
+                    if ( ! Double.isNaN( gy ) ) {
+                        tracer.addVertex( isY ? gy : gx, isY ? gx : gy, color );
                     }
                 }
             }
             tracer.flush();
             if ( style.showmean_ ) {
                 double dx = mean_;
-                Axis[] axes = surface.getAxes();
-                double gx = axes[ 0 ].dataToGraphics( dx );
-                double gylo = axes[ 1 ].dataToGraphics( 0 );
-                double gyhi = axes[ 1 ].dataToGraphics( factor );
+                double gx = xAxis.dataToGraphics( dx );
+                double gylo = yAxis.dataToGraphics( 0 );
+                double gyhi = yAxis.dataToGraphics( factor );
                 LineTracer meanTracer =
                     style.createLineTracer( g2, box, 3, isBitmap );
-                meanTracer.addVertex( gx, gylo, color );
-                meanTracer.addVertex( gx, gyhi, color );
+                if ( isY ) {
+                    meanTracer.addVertex( gylo, gx, color );
+                    meanTracer.addVertex( gyhi, gx, color );
+                }
+                else {
+                    meanTracer.addVertex( gx, gylo, color );
+                    meanTracer.addVertex( gx, gyhi, color );
+                }
                 meanTracer.flush();
             }
         }
@@ -518,8 +530,9 @@ public class Stats1Plotter implements Plotter<Stats1Plotter.StatsStyle> {
          * @param  style     stats style
          */
         private double getFactor( PlanarSurface surface, StatsStyle style ) {
-            double[] xlims = surface.getDataLimits()[ 0 ];
-            boolean isTime = surface.getTimeFlags()[ 0 ];
+            boolean isY = style.isY_;
+            double[] xlims = surface.getDataLimits()[ isY ? 1 : 0 ];
+            boolean isTime = surface.getTimeFlags()[ isY ? 1 : 0 ];
             Rounding xround = Rounding.getRounding( isTime );
             return getFactor( xlims[ 0 ], xlims[ 1 ], xround, style );
         }
