@@ -24,6 +24,7 @@ import uk.ac.starlink.table.StarTableFactory;
 import uk.ac.starlink.table.StoragePolicy;
 import uk.ac.starlink.table.TableFormatException;
 import uk.ac.starlink.table.TableScheme;
+import uk.ac.starlink.table.Tables;
 import uk.ac.starlink.ttools.DocUtils;
 import uk.ac.starlink.ttools.filter.AddColumnFilter;
 import uk.ac.starlink.ttools.filter.AddSkyCoordsFilter;
@@ -72,11 +73,11 @@ public class SkySimScheme implements TableScheme, Documented {
             "when no suitable real dataset of the required size",
             "is available.",
             "In the current implementation the row count,",
-            "which may be given in integer or exponential notation,",
             "is the only parameter,",
             "so the specification",
             "\"<code>:" + getSchemeName() + ":5e6</code>\"",
             "would give a 5 million-row simulated catalogue.",
+            "The row count" + Tables.PARSE_COUNT_MAY_BE_GIVEN,
             "</p>",
             "<p>The current implementation provides somewhat realistic",
             "position-dependent star densities and",
@@ -100,7 +101,7 @@ public class SkySimScheme implements TableScheme, Documented {
         try {
             nrow = argtxt.length() == 0
                  ? 10000
-                 : (long) Double.parseDouble( argtxt );
+                 : Tables.parseCount( argtxt );
         }
         catch ( NumberFormatException e ) {
             throw new TableFormatException( "Not numeric: " + argtxt, e );
