@@ -29,6 +29,7 @@ import uk.ac.starlink.ttools.votlint.VocabChecker;
 import uk.ac.starlink.util.Compression;
 import uk.ac.starlink.util.ContentType;
 import uk.ac.starlink.util.DOMUtils;
+import uk.ac.starlink.util.URLUtils;
 import uk.ac.starlink.vo.DatalinkVersion;
 import uk.ac.starlink.vo.Ivoid;
 import uk.ac.starlink.vo.datalink.LinkColMap;
@@ -714,7 +715,7 @@ public class DatalinkValidator {
                                       "Multiple columns named " + name );
                 }
                 else if ( coldef.getContentClass().isAssignableFrom( clazz ) ) {
-                    icolMap.put( coldef, new Integer( ic ) );
+                    icolMap.put( coldef, Integer.valueOf( ic ) );
                 }
             }
             else {
@@ -807,10 +808,10 @@ public class DatalinkValidator {
         /* But perform some additional checks for things that the
          * library code just ignores. */
         Map<String,Integer> paramCounts = new HashMap<String,Integer>();
-        paramCounts.put( "accessURL", new Integer( 0 ) );
-        paramCounts.put( "standardID", new Integer( 0 ) );
-        paramCounts.put( "resourceIdentifier", new Integer( 0 ) );
-        paramCounts.put( "contentType", new Integer( 0 ) );
+        paramCounts.put( "accessURL", Integer.valueOf( 0 ) );
+        paramCounts.put( "standardID", Integer.valueOf( 0 ) );
+        paramCounts.put( "resourceIdentifier", Integer.valueOf( 0 ) );
+        paramCounts.put( "contentType", Integer.valueOf( 0 ) );
         for ( VOElement pEl : resourceEl.getChildrenByName( "PARAM" ) ) {
             ParamElement paramEl = (ParamElement) pEl;
             String name = paramEl.getName();
@@ -836,7 +837,7 @@ public class DatalinkValidator {
                         .toString();
                     reporter_.report( DatalinkCode.E_PSNS, msg );
                 }
-                paramCounts.put( name, new Integer( count + 1 ) );
+                paramCounts.put( name, Integer.valueOf( count + 1 ) );
             }
         }
         for ( Map.Entry<String,Integer> entry : paramCounts.entrySet() ) {
@@ -986,7 +987,7 @@ public class DatalinkValidator {
             }
             else {
                 try {
-                    new URL( accessUrl );
+                    URLUtils.newURL( accessUrl );
                 }
                 catch ( MalformedURLException e ) {
                     String msg = new StringBuffer()
@@ -1155,7 +1156,7 @@ public class DatalinkValidator {
             /* Check access_url content. */
             if ( accessUrl != null ) {
                 try {
-                    URL url = new URL( accessUrl );
+                    URL url = URLUtils.newURL( accessUrl );
                     String msg = new StringBuffer()
                         .append( "Row " )
                         .append( jrow )
