@@ -71,6 +71,7 @@ public enum FixedCode implements ReportCode {
     E_EXIO( "Error reading examples document" ),
     E_EXPA( "Badly formed XML examples document" ),
     E_EXVC( "Incorrect examples RDFa vocab attribute" ),
+    E_EXVP( "Unknown semantics term in RDFa property attribute" ),
     E_FKIO( "Error reading TAP_SCHEMA.keys table" ),
     E_FKLK( "Foreign key link broken" ),
     E_FKNT( "Foreign key target table absent" ),
@@ -218,7 +219,6 @@ public enum FixedCode implements ReportCode {
     W_CRGN( "Unknown DALI region xtype" ),
     W_CTYP( "Datatype possible mismatch" ),
     W_CUCD( "UCD mismatch" ),
-    W_CULF( "Custom language feature type" ),
     W_CUNI( "Unit mismatch" ),
     W_CUTP( "UType mismatch" ),
     W_DMDC( "DataModel not declared" ),
@@ -232,6 +232,7 @@ public enum FixedCode implements ReportCode {
     W_EXUL( "Undeclared query language" ),
     W_EXVC( "Potentially problematic examples RDFa vocab attribute" ),
     W_EXVL( "Example query does not validate" ),
+    W_EXVP( "Preliminary/deprecated semantics term in RDFa property att" ),
     W_FKUN( "Keys content" ),
     W_FLUN( "Key columns content" ),
     W_FTYP( "Foreign key type mismatch" ),
@@ -306,6 +307,7 @@ public enum FixedCode implements ReportCode {
 
     I_CDET( "No column metadata from /tables" ),
     I_CJOB( "Job created" ),
+    I_CULF( "Custom language feature type" ),
     I_CURL( "Reading capability metadata" ),
     I_DMID( "Data model declared" ),
     I_DQUR( "QUERY_STATUS redundancy" ),
