@@ -7,9 +7,12 @@ import java.io.IOException;
 import java.lang.reflect.Array;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.BitSet;
 import java.util.List;
 import java.util.function.Function;
+import java.util.logging.Level;
 import java.util.logging.Logger;
+import java.util.regex.Pattern;
 import uk.ac.starlink.table.AbstractStarTable;
 import uk.ac.starlink.table.ColumnInfo;
 import uk.ac.starlink.table.DescribedValue;
@@ -18,6 +21,7 @@ import uk.ac.starlink.table.JoinStarTable;
 import uk.ac.starlink.table.RowSequence;
 import uk.ac.starlink.table.RowSplittable;
 import uk.ac.starlink.table.RowStore;
+import uk.ac.starlink.table.RowSubsetStarTable;
 import uk.ac.starlink.table.StarTable;
 import uk.ac.starlink.table.StarTableFactory;
 import uk.ac.starlink.table.StoragePolicy;
@@ -32,6 +36,7 @@ import uk.ac.starlink.task.ParameterValueException;
 import uk.ac.starlink.task.StringParameter;
 import uk.ac.starlink.task.TaskException;
 import uk.ac.starlink.ttools.filter.ProcessingStep;
+import uk.ac.starlink.ttools.jel.ColumnIdentifier;
 import uk.ac.starlink.ttools.jel.JELRowReader;
 import uk.ac.starlink.ttools.jel.JELUtils;
 import uk.ac.starlink.ttools.jel.SequentialJELRowReader;
@@ -47,9 +52,11 @@ import uk.ac.starlink.util.IOFunction;
 public class ArrayJoin extends SingleMapperTask {
 
     private final ExpressionInputTableParameter atableParam_;
+    private final BooleanParameter keepallParam_;
     private final InputFormatParameter afmtParam_;
     private final FilterParameter acmdParam_;
     private final BooleanParameter astreamParam_;
+    private final StringParameter aparamsParam_;
     private final BooleanParameter cacheParam_;
     private final JoinFixActionParameter fixcolsParam_;
     private final StringParameter asuffixParam_;
@@ -95,6 +102,46 @@ public class ArrayJoin extends SingleMapperTask {
         astreamParam_ = atableParam_.getStreamParameter();
         acmdParam_.setTableDescription( "array tables", atableParam_, true );
 
+        aparamsParam_ = new StringParameter( "aparams" );
+        aparamsParam_.setPrompt( "Parameters from external tables to include" );
+        aparamsParam_.setUsage( "<name-list>" );
+        aparamsParam_.setNullPermitted( true );
+        aparamsParam_.setDescription( new String[] {
+            "<p>Lists the table parameters (per-table metadata)",
+            "that will be read from loaded tables",
+            "and turned into scalar-valued columns in the output.",
+            "By default parameters are discarded,",
+            "but you can include them in the output by naming them",
+            "using this parameter.",
+            "</p>",
+            "<p>Parameters are supplied as a space- or comma-separated list.",
+            "Matching against table names is case-insensitive,",
+            "and the asterisk character \"<code>*</code>\" may be used",
+            "as a wildcard to match any sequence of characters.",
+            "The list is interpreted relative to the first external table",
+            "which is loaded.",
+            "Supplying the value \"<code>*</code>\" therefore will include",
+            "a column for each parameter in the first loaded table.",
+            "</p>",
+        } );
+
+        keepallParam_ = new BooleanParameter( "keepall" );
+        keepallParam_.setPrompt( "Retain rows without array table?" );
+        keepallParam_.setBooleanDefault( true );
+        keepallParam_.setDescription( new String[] {
+            "<p>This parameter determines what happens when the",
+            "<code>" + atableParam_.getName() + "</code> parameter",
+            "does not name a table that can be loaded.",
+            "If this parameter is false,",
+            "the input table row is output with blank values in the columns",
+            "supplied by the array tables,",
+            "so that the output table has the same number of rows as the",
+            "input table.",
+            "If it is true, only rows with successfully loaded tables",
+            "are included in the output.",
+            "</p>",
+        } );
+
         cacheParam_ = new BooleanParameter( "cache" );
         cacheParam_.setPrompt( "Cache array values?" );
         cacheParam_.setBooleanDefault( true );
@@ -129,6 +176,8 @@ public class ArrayJoin extends SingleMapperTask {
             afmtParam_,
             astreamParam_,
             acmdParam_,
+            keepallParam_,
+            aparamsParam_,
             cacheParam_,
             fixcolsParam_,
             asuffixParam_,
@@ -143,7 +192,9 @@ public class ArrayJoin extends SingleMapperTask {
         String fmt = afmtParam_.stringValue( env );
         boolean stream = astreamParam_.booleanValue( env );
         final ProcessingStep[] asteps = acmdParam_.stepsValue( env );
-        StarTableFactory tfact = LineTableEnvironment.getTableFactory( env);
+        final boolean keepAll = keepallParam_.booleanValue( env );
+        final String aparamsTxt = aparamsParam_.stringValue( env );
+        StarTableFactory tfact = LineTableEnvironment.getTableFactory( env );
         boolean allowMissing = true;
         boolean isCached = cacheParam_.booleanValue( env );
         final IOFunction<String,StarTable> atableReader = loc -> {
@@ -154,6 +205,8 @@ public class ArrayJoin extends SingleMapperTask {
             }
             catch ( IOException e ) {
                 if ( allowMissing ) {
+                    logger_.log( Level.INFO,
+                                 "Table load failed for " + loc, e );
                     return null;
                 }
                 else {
@@ -179,6 +232,9 @@ public class ArrayJoin extends SingleMapperTask {
         return new TableProducer() {
             public StarTable getTable() throws IOException, TaskException {
                 final StarTable inTable = inProd.getTable();
+
+                /* Prepare the table which will supply just the
+                 * array columns. */
                 final Function<Library,CompiledExpression> alocCompiler;
                 try {
                     alocCompiler =
@@ -191,17 +247,91 @@ public class ArrayJoin extends SingleMapperTask {
                 }
                 ArrayDataTable seqArrayTable =
                     createSequentialArrayTable( inTable, alocCompiler,
-                                                atableReader );
+                                                atableReader, keepAll,
+                                                aparamsTxt );
+
+                /* Cache just those columns if requested. */
                 StarTable arrayTable = isCached
                                      ? cacheArrayTable( seqArrayTable )
                                      : seqArrayTable;
-                StarTable[] tables = { inTable, arrayTable };
+
+                /* Now prepare the input table for joining to the arrays table.
+                 * If all rows of the input table will be output,
+                 * that's just the input table itself. */
+                final StarTable inTable1;
+                if ( keepAll ) {
+                    inTable1 = inTable;
+                }
+
+                /* If we want only to output those rows with non-blank
+                 * array columns, we need a bit mask to indicate which
+                 * rows they are, obtained from the arrays table.
+                 * There are ways to do this by streaming rather than
+                 * preparing a bit mask up front, but they are all a pain,
+                 * especially to get them working with both caching modes. */
+                else {
+
+                    /* If we have cached the arrays, which is the usual case,
+                     * this information is already stored.
+                     * If not we have to calculate it here; iterating over
+                     * the rows will force this.  That does look inefficient,
+                     * but it's only going to happen in the non-cached case,
+                     * for which performance warnings are already posted. */
+                    if ( seqArrayTable.rowMask_ == null ) {
+                        assert ! isCached;
+                        try ( RowSequence rseq =
+                                  seqArrayTable.getRowSequence() ) {
+                            while ( rseq.next() ) {
+                                rseq.getRow();
+                            }
+                        }
+                    }
+                    BitSet rowMask = seqArrayTable.rowMask_;
+                    assert rowMask != null;
+                    inTable1 = new RowSubsetStarTable( inTable, rowMask );
+                }
+
+                /* Join and return the (possibly filtered) input table
+                 * and the arrays table. */
+                StarTable[] tables = { inTable1, arrayTable };
                 JoinFixAction[] fixacts = { inFixact, aFixact };
                 return new JoinStarTable( tables, fixacts );
             }
         };
     }
 
+    /**
+     * Tests whether a token matches a pattern.
+     * The pattern is supplied as a sequence of zero or more
+     * space- or comma-separated items,
+     * each of which can contain an asterisk to denote simple wildcarding.
+     * Currently not case sensitive.  Empty tokens and patterns do not match.
+     *
+     * @param   pattern   pattern
+     * @param   token  token to find
+     * @return  true iff token is described by pattern
+     */
+    private static boolean isNameMatch( String pattern, String token ) {
+        boolean isCaseSensitive = false;
+        if ( token != null && token.trim().length() > 0 ) {
+            for ( String patItem : pattern.split( "[\\s,]+", 0 ) ) {
+                if ( isCaseSensitive ? token.equals( patItem )
+                                     : token.equalsIgnoreCase( patItem ) ) {
+                    return true;
+                }
+                else {
+                    Pattern regex =
+                        ColumnIdentifier.globToRegex( patItem,
+                                                      isCaseSensitive );
+                    if ( regex != null && regex.matcher( token ).matches() ) {
+                        return true;
+                    }
+                }
+            }
+        }
+        return false;
+    }
+
     /**
      * Generates the joined table given required information.
      *
@@ -209,24 +339,30 @@ public class ArrayJoin extends SingleMapperTask {
      * @param  alocCompiler  produces location of array table
      *                       for input table row
      * @param  atableLoader  loads an array table given a location
+     * @param  keepAll  true to retain all input rows,
+     *                  false to retain only ones with array tables
+     * @param  paramsTxt   pattern for matching table parameters to
+     *                     include as scalar-valued columns
      * @return   non-random table joining input and arrays
      */
     private static ArrayDataTable
             createSequentialArrayTable(
                     StarTable inTable,
                     Function<Library,CompiledExpression> alocCompiler,
-                    IOFunction<String,StarTable> atableLoader )
+                    IOFunction<String,StarTable> atableLoader,
+                    boolean keepAll, String paramsTxt )
             throws IOException, TaskException {
-
-        /* Read through the input table to find the first array table.
-         * We will use this as a template supplying the array column
-         * metadata. */
         SequentialJELRowReader inRdr0 = new SequentialJELRowReader( inTable );
         Library lib = JELUtils.getLibrary( inRdr0 );
         CompiledExpression alocCompex = alocCompiler.apply( lib );
+
+        /* Read through the input table to find the first array table.
+         * We will use this as a template supplying the array column metadata.
+         * It would be possible to do the whole thing in one pass rather than
+         * one-and-a-bit for the case keepAll=false, but it's fiddly. */
         int[] rowIndex = new int[] { -1 };
         StarTable atable0 = readFirstArrayTable( inTable, alocCompiler,
-                                                 atableLoader, rowIndex);
+                                                 atableLoader, rowIndex );
         if ( atable0 == null ) {
             throw new TaskException( "No array tables" ); 
         }
@@ -248,14 +384,28 @@ public class ArrayJoin extends SingleMapperTask {
             }
         }
         ArrayColumn<?>[] acols = acolList.toArray( new ArrayColumn<?>[ 0 ] );
-        if ( acols.length == 0 ) {
-            throw new ExecutionException( "No suitable columns "
+
+        /* Prepare typed parameter handlers if required. */
+        List<ValueInfo> pinfoList = new ArrayList<>();
+        if ( paramsTxt != null && paramsTxt.trim().length() > 0 ) {
+            for ( DescribedValue dval : atable0.getParameters() ) {
+                ValueInfo pinfo = dval.getInfo();
+                if ( isNameMatch( paramsTxt, pinfo.getName() ) ) {
+                    pinfoList.add( pinfo );
+                }
+            }
+        }
+        ValueInfo[] pinfos = pinfoList.toArray( new ValueInfo[ 0 ] );
+
+        /* Check there is some work to do. */
+        if ( acols.length == 0 && pinfos.length == 0 ) {
+            throw new ExecutionException( "No suitable columns/parameters "
                                         + "in template array table" );
         }
 
         /* Create and return a table ready to read the data. */
-        return new ArrayDataTable( inTable, acols, alocCompiler, atableLoader,
-                                   irow0 );
+        return new ArrayDataTable( inTable, acols, pinfos,
+                                   alocCompiler, atableLoader, keepAll, irow0 );
     }
 
     /**
@@ -361,14 +511,18 @@ public class ArrayJoin extends SingleMapperTask {
      * all the data from a table column.
      *
      * @param   acols  defines the columns to be read
+     * @param   pinfos  table parameters to read
      * @param   atable  array table to read
-     * @param   irow   index of input table for this array table
+     * @param   irow   index of input table for this array table,
+     *                 used for user messages only
      * @return   array of typed arrays, one for each element of acols
      */
     private static Object[] readArrayData( ArrayColumn<?>[] acols,
+                                           ValueInfo[] pinfos,
                                            StarTable atable, long irow )
             throws IOException {
         int na = acols.length;
+        int np = pinfos.length;
 
         /* It makes life much easier if we know the number of rows.
          * Since these tables are not expected to be all that large,
@@ -381,6 +535,17 @@ public class ArrayJoin extends SingleMapperTask {
         }
         assert nrow >= 0;
 
+        /* Read the parameters if required. */
+        Object[] pdata = new Object[ np ];
+        for ( int ip = 0; ip < np; ip++ ) {
+            ValueInfo pinfo = pinfos[ ip ];
+            DescribedValue dval = atable.getParameterByName( pinfo.getName() );
+            Object value = dval == null ? null : dval.getValue();
+            if ( pinfo.getContentClass().isInstance( value ) ) {
+                pdata[ ip ] = value;
+            }
+        }
+
         /* Check the columns look like we are expecting and
          * prepare array storage. */
         Object[] adata = new Object[ na ];
@@ -391,9 +556,9 @@ public class ArrayJoin extends SingleMapperTask {
             if ( ! gotInfo.getContentClass()
                           .equals( templateInfo.getContentClass() ) ||
                  ! gotInfo.getName().equals( templateInfo.getName() ) ) {
-                throw new IOException( "Table data mismatch at row " + irow
-                                     + "; " + gotInfo + " does not match "
-                                     + templateInfo );
+                throw new IOException( "Table data mismatch at input row "
+                                     + irow + "; " + gotInfo
+                                     + " does not match " + templateInfo );
             }
             adata[ ia ] = acol.createArray( nrow );
         }
@@ -411,8 +576,16 @@ public class ArrayJoin extends SingleMapperTask {
             }
         }
 
-        /* Return populated arrays. */
-        return adata;
+        /* Return populated array. */
+        if ( np > 0 ) {
+            Object[] data = new Object[ na + np ];
+            System.arraycopy( adata, 0, data, 0, na );
+            System.arraycopy( pdata, 0, data, na, np );
+            return data;
+        }
+        else {
+            return adata;
+        }
     }
 
     /**
@@ -558,7 +731,7 @@ public class ArrayJoin extends SingleMapperTask {
         abstract A createArray( int n );
 
         /**
-         * Stores a single element in an storage array.
+         * Stores a single element in a storage array.
          *
          * @param  value  value to store, expected of suitable type
          * @param  ix     element index
@@ -589,37 +762,74 @@ public class ArrayJoin extends SingleMapperTask {
 
         final StarTable base_;
         final ArrayColumn<?>[] arrayCols_;
+        final ValueInfo[] paramInfos_;
         final Function<Library,CompiledExpression> alocCompiler_;
         final IOFunction<String,StarTable> atableLoader_;
+        final boolean keepAll_;
         final int irow0_;
+        final int nacol_;
+        final int npcol_;
         final int ncol_;
+        final Object[] emptyRow_;
+        final ColumnInfo[] colInfos_;
         final static int UNKNOWN_DIM = -1;
         final static int VARIABLE_DIM = -2;
         int[] arrayDims_;
+        BitSet rowMask_;
 
         /**
          * Constructor.
          *
          * @param  base  input table
          * @param  arrayCols   array of objects describing the
-         *                     columns coming from external array tables
+         *                     array-valued columns coming from
+         *                     external array tables
+         * @param  paramInfos   definitions of table parameters describing
+         *                      the scalar-valued columns coming from
+         *                      external array tables
          * @param  alocCompiler  produces location of array table
          *                       for input table row
          * @param  atableLoader  loads an array table given a location
+         * @param  keepAll  true to retain all input rows,
+         *                  false to retain only ones with array tables
          * @param  irow0  index of the first row known to contain a
          *                usable array table; array values can be
          *                assumed missing for any earlier rows
          */
         ArrayDataTable( StarTable base, ArrayColumn<?>[] arrayCols,
+                        ValueInfo[] paramInfos,
                         Function<Library,CompiledExpression> alocCompiler,
                         IOFunction<String,StarTable> atableLoader,
-                        int irow0 ) {
+                        boolean keepAll, int irow0 ) {
             base_ = base;
             arrayCols_ = arrayCols;
+            paramInfos_ = paramInfos;
             alocCompiler_ = alocCompiler;
             atableLoader_ = atableLoader;
+            keepAll_ = keepAll;
             irow0_ = irow0;
-            ncol_ = arrayCols.length;
+            nacol_ = arrayCols.length;
+            npcol_ = paramInfos.length;
+            ncol_ = nacol_ + npcol_;
+            colInfos_ = new ColumnInfo[ ncol_ ];
+            for ( int ia = 0; ia < nacol_; ia++ ) {
+                colInfos_[ ia ] = arrayCols_[ ia ].arrayInfo_;
+            }
+            for ( int ip = 0; ip < npcol_; ip++ ) {
+                colInfos_[ nacol_ + ip ] = new ColumnInfo( paramInfos[ ip ] );
+            }
+            emptyRow_ = new Object[ ncol_ ];
+        }
+
+        /**
+         * Indicates whether a row produced by this table corresponds to
+         * a case where no external table was loaded.
+         *
+         * @param  row  candidate row object
+         * @return   true iff <code>row</code> is an intentionally empty row
+         */
+        public boolean isEmptyRow( Object[] row ) {
+            return row == emptyRow_;
         }
 
         public boolean isRandom() {
@@ -631,30 +841,49 @@ public class ArrayJoin extends SingleMapperTask {
         }
 
         public ColumnInfo getColumnInfo( int icol ) {
-            return arrayCols_[ icol ].arrayInfo_;
+            return colInfos_[ icol ];
         }
 
         public long getRowCount() {
-            return base_.getRowCount();
+            return keepAll_ ? base_.getRowCount() : -1;
         }
 
         public RowSequence getRowSequence() throws IOException {
             SequentialJELRowReader inRdr = new SequentialJELRowReader( base_ );
             Library lib = JELUtils.getLibrary( inRdr );
             final CompiledExpression alocCompex = alocCompiler_.apply( lib );
-            final int[] adims = new int[ ncol_ ];
-            final Object[] emptyRow = new Object[ ncol_ ];
+            final int[] adims = new int[ nacol_ ];
             Arrays.fill( adims, UNKNOWN_DIM );
+            BitSet rowMask = new BitSet();
             return new RowSequence() {
                 Object[] adata_;
                 int irow_ = -1;
+                boolean finished_;
+                boolean tryAll_ = true;
                 public boolean next() throws IOException {
+                    if ( irow_ >= 0 ) {
+                        tryAll_ = tryAll_ && adata_ != null;
+                    }
                     adata_ = null;
-                    if ( inRdr.next() ) {
-                        irow_++;
-                        return true;
+                    if ( keepAll_ ) {
+                        if ( inRdr.next() ) {
+                            irow_++;
+                            return true;
+                        }
+                        else {
+                            finished_ = true;
+                            return false;
+                        }
                     }
                     else {
+                        while ( inRdr.next() ) {
+                            irow_++;
+                            adata_ = null;
+                            if ( ! isEmptyRow( getArrayData() ) ) {
+                                return true;
+                            }
+                        }
+                        finished_ = true;
                         return false;
                     }
                 }
@@ -667,17 +896,18 @@ public class ArrayJoin extends SingleMapperTask {
                 public void close() throws IOException {
                     adata_ = null;
                     inRdr.close();
-                    arrayDims_ = adims.clone();
+                    if ( finished_ && tryAll_ ) {
+                        arrayDims_ = adims.clone();
+                        rowMask_ = rowMask;
+                    }
                 }
 
                 /**
-                 * Returns an array of arrays giving the array-valued cells
-                 * at the current row for each of the array columns
-                 * managed by this sequence.
+                 * Returns the contents of the current row.
                  * The data is acquired lazily.
                  *
-                 * @return  ncol-element array of arrays,
-                 *          or null if no array data this row
+                 * @return  ncol-element array of values,
+                 *          or <code>emptyRow_</code> if no data in this row
                  */
                 Object[] getArrayData() throws IOException {
                     if ( adata_ == null ) {
@@ -687,34 +917,35 @@ public class ArrayJoin extends SingleMapperTask {
                             try ( StarTable aTable =
                                       atableLoader_.apply( aloc ) ) {
                                 adata = aTable == null
-                                      ? emptyRow
-                                      : readArrayData( arrayCols_, aTable,
-                                                       irow_ );
+                                      ? emptyRow_
+                                      : readArrayData( arrayCols_, paramInfos_,
+                                                       aTable, irow_ );
                             }
-                            if ( adata != emptyRow ) {
-                                for ( int ic = 0; ic < ncol_; ic++ ) {
-                                    Object array = adata[ ic ];
+                            if ( adata != emptyRow_ ) {
+                                for ( int ia = 0; ia < nacol_; ia++ ) {
+                                    Object array = adata[ ia ];
                                     if ( array != null ) {
                                         int n = Array.getLength( array );
                                         if ( n > 0 ) {
-                                            if ( adims[ ic ] == UNKNOWN_DIM ) {
-                                                adims[ ic ] = n;
+                                            if ( adims[ ia ] == UNKNOWN_DIM ) {
+                                                adims[ ia ] = n;
                                             }
-                                            else if ( adims[ ic ] > 0 &&
-                                                      n != adims[ ic ] ) {
-                                                adims[ ic ] = VARIABLE_DIM;
+                                            else if ( adims[ ia ] > 0 &&
+                                                      n != adims[ ia ] ) {
+                                                adims[ ia ] = VARIABLE_DIM;
                                             }
-                                            assert adims[ ic ] == VARIABLE_DIM
-                                                || adims[ ic ] == n;
+                                            assert adims[ ia ] == VARIABLE_DIM
+                                                || adims[ ia ] == n;
                                         }
                                     }
                                 }
                             }
                         }
                         else {
-                            adata = null;
+                            adata = emptyRow_;
                         }
                         adata_ = adata;
+                        rowMask.set( irow_, adata_ != emptyRow_ );
                     }
                     return adata_;
                 }
@@ -734,14 +965,21 @@ public class ArrayJoin extends SingleMapperTask {
          * @return   best available metadata for column
          */
         ColumnInfo getEnhancedColumnInfo( int icol ) {
-            ColumnInfo info = new ColumnInfo( arrayCols_[ icol ].arrayInfo_ );
-            int adim = arrayDims_ == null
-                     ? UNKNOWN_DIM
-                     : arrayDims_[ icol ];
-            if ( adim > 0 ) {
-                info.setShape( new int[] { adim } );
+            int iacol = icol;
+            if ( iacol < nacol_ ) { 
+                ColumnInfo info =
+                    new ColumnInfo( arrayCols_[ iacol ].arrayInfo_ );
+                int adim = arrayDims_ == null
+                         ? UNKNOWN_DIM
+                         : arrayDims_[ iacol ];
+                if ( adim > 0 ) {
+                    info.setShape( new int[] { adim } );
+                }
+                return info;
+            }
+            else {
+                return colInfos_[ icol ];
             }
-            return info;
         }
 
         // boilerplate 
