@@ -34,6 +34,7 @@ public class TableFactoryParameter extends Parameter<StarTableFactory> {
      *
      * @param   name   parameter name
      */
+    @SuppressWarnings("this-escape")
     public TableFactoryParameter( String name ) {
         super( name, StarTableFactory.class, true );
         setUsage( FILE_OPTION +
@@ -136,7 +137,9 @@ public class TableFactoryParameter extends Parameter<StarTableFactory> {
             String clazzname = sval.substring( LOCCLASS_PREFIX.length() );
             TableLocator tloc;
             try {
-                tloc = (TableLocator) Class.forName( clazzname ).newInstance();
+                tloc = (TableLocator) Class.forName( clazzname )
+                                           .getDeclaredConstructor()
+                                           .newInstance();
             }
             catch ( Throwable e ) {
                 throw new UsageException( "Bad TableLocator class name", e );
