@@ -20,6 +20,7 @@ import uk.ac.starlink.task.ParameterValueException;
 import uk.ac.starlink.task.StringParameter;
 import uk.ac.starlink.task.TaskException;
 import uk.ac.starlink.util.ContentCoding;
+import uk.ac.starlink.util.IOSupplier;
 import uk.ac.starlink.vo.AdqlSyntax;
 import uk.ac.starlink.vo.AdqlValidator;
 import uk.ac.starlink.vo.TapQuery;
@@ -230,7 +231,8 @@ public class TapMapper implements TableMapper {
 
     public TableMapping createMapping( Environment env, final int nup )
             throws TaskException {
-        final TapService tapService = tapserviceParams_.getTapService( env );
+        final IOSupplier<TapService> tapServiceSupplier =
+            tapserviceParams_.getServiceSupplier( env );
         final String adql = adqlParam_.stringValue( env );
         if ( parseParam_.booleanValue( env ) ) {
             AdqlValidator validator = AdqlValidator.createValidator();
@@ -268,6 +270,7 @@ public class TapMapper implements TableMapper {
             return new TableMapping() {
                 public StarTable mapTables( InputTableSpec[] inSpecs )
                         throws TaskException, IOException {
+                    TapService tapService = tapServiceSupplier.get();
                     TapQuery tq =
                         createTapQuery( tapService, adql, extraParams, upNames,
                                         inSpecs, uploadLimit, vowriter );
@@ -286,6 +289,7 @@ public class TapMapper implements TableMapper {
             return new TableMapping() {
                 public StarTable mapTables( InputTableSpec[] inSpecs )
                         throws TaskException, IOException {
+                    TapService tapService = tapServiceSupplier.get();
                     TapQuery tq =
                         createTapQuery( tapService, adql, extraParams, upNames,
                                         inSpecs, uploadLimit, vowriter );
@@ -307,6 +311,79 @@ public class TapMapper implements TableMapper {
         }
     }
 
+    /**
+     * Returns the TapServiceParams used by this mapper
+     * to acquire a TAP service.
+     *
+     * @return  tap service params
+     */
+    public TapServiceParams getTapServiceParams() {
+        return tapserviceParams_;
+    }
+
+    /**
+     * Returns the parameter used to acquire ADQL query text.
+     *
+     * @return  adql parameter
+     */
+    public Parameter<String> getAdqlParameter() {
+        return adqlParam_;
+    }
+
+    /**
+     * Returns the parameter used to acquire the sync/async flag.
+     *
+     * @return  sync parameter
+     */
+    public Parameter<Boolean> getSyncParameter() {
+        return syncParam_;
+    }
+
+    /**
+     * Returns the parameter used to acquire the query language variant.
+     *
+     * @return  language parameter
+     */
+    public Parameter<String> getLanguageParameter() {
+        return langParam_;
+    }
+
+    /**
+     * Returns the parameter used to acquire the output record limit.
+     *
+     * @return  maxrec parameter
+     */
+    public Parameter<Long> getMaxrecParameter() {
+        return maxrecParam_;
+    }
+
+    /**
+     * Returns the parameter used to acquire the content coding.
+     *
+     * @return  content coding parameter
+     */
+    public ContentCodingParameter getContentCodingParameter() {
+        return codingParam_;
+    }
+
+    /**
+     * Returns the parameter used to acquire the table upload writer.
+     *
+     * @return  upload writer parameter
+     */
+    public Parameter<VOTableWriter> getVOTableWriterParameter() {
+        return vowriterParam_;
+    }
+
+    /**
+     * Returns the result reader used by this mapper.
+     *
+     * @return  result reader
+     */
+    public TapResultReader getResultReader() {
+        return resultReader_;
+    }
+
     /**
      * Returns a new TapQuery object from values available at execution time.
      *
@@ -347,7 +424,7 @@ public class TapMapper implements TableMapper {
      * @param   label  parameter suffix 
      * @return   upload name parameter
      */
-    private static Parameter<String> createUploadNameParameter( String label ) {
+    public static Parameter<String> createUploadNameParameter( String label ) {
         StringParameter upnameParam = new StringParameter( "upname" + label ) {
             @Override
             public String stringToObject( Environment env, String inval )
