@@ -1,5 +1,7 @@
 package uk.ac.starlink.ttools.task;
 
+import java.util.Arrays;
+import java.util.stream.Collectors;
 import java.lang.reflect.Array;
 import uk.ac.starlink.task.Environment;
 import uk.ac.starlink.task.Parameter;
@@ -108,6 +110,13 @@ public class WordsParameter<W> extends Parameter<W[]> {
         return parseWords( stringToWords( sval ) );
     }
 
+    @Override
+    public String objectToString( Environment env, W[] words ) {
+        return Arrays.stream( words )
+                     .map( String::valueOf )
+                     .collect( Collectors.joining( " " ) );
+    }
+
     /**
      * Splits a given string value into words.
      * A TaskException is thrown if the number of words does not match
