@@ -15,6 +15,7 @@ import java.util.Set;
 import java.util.TreeSet;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+import uk.ac.starlink.util.URLUtils;
 import uk.ac.starlink.vo.VocabTerm;
 import uk.ac.starlink.vo.Vocabulary;
 
@@ -75,13 +76,20 @@ public class VocabChecker {
                           } );
 
     /** Instance for vocabulary at http://www.ivoa.net/rdf/product-type. */
-    /* Term list is from https://www.ivoa.net/rdf/product-type/2021-11-18/;
-     * at time of writing all terms are marked Preliminary. */
+    /* Term list is from https://www.ivoa.net/rdf/product-type/2024-03-22/
+     * as amended by VEP-014. */
     public static final VocabChecker PRODUCT_TYPE =
         new VocabChecker( "http://www.ivoa.net/rdf/product-type",
                           new String[] {
-                              "cube", "dynamic-spectrum", "event", "image",
-                              "measurements", "sed", "spectrum", "timeseries",
+                              "cube", "dynamic-spectrum", "event-list",
+                              "image", "light-curve", "measurements",
+                              "polarization-cube",
+                              "polarization-resolved-dataset",
+                              "polarized-spectrum", "sed", "slit-spectrum",
+                              "spatially-resolved-dataset", "spatial-profile",
+                              "spectral-cube", "spectrally-resolved-dataset",
+                              "spectrum", "temporally-resolved-dataset",
+                              "time-cube", "timeseries", "velocity-curve",
                               "visibility",
                           } );
 
@@ -121,7 +129,7 @@ public class VocabChecker {
      */
     public VocabChecker( String vocabUrl, String[] fixedTerms ) {
         try {
-            vocabUrl_ = new URL( vocabUrl );
+            vocabUrl_ = URLUtils.newURL( vocabUrl );
         }
         catch ( MalformedURLException e ) {
             throw new IllegalArgumentException( "Not a URL: " + vocabUrl );
