@@ -24,6 +24,7 @@ public class TimesTest extends TestCase {
         assertEquals( 53303.5, Times.isoToMjd( "2004-10-25T12:00" ) );
         assertEquals( 53303.5, Times.isoToMjd( "2004-10-25T12" ) );
         assertEquals( 53303.0, Times.isoToMjd( "2004-10-25" ) );
+        assertEquals( 53303.0, Times.isoToMjd( "2004-10-25Z" ) );
 
         assertEquals( "2004-10-25T12:00:00", Times.mjdToIso( 53303.5 ) );
         assertEquals( "18:00:00", Times.mjdToTime( -0.25 ) );
@@ -132,6 +133,15 @@ public class TimesTest extends TestCase {
         assertEquals( 0, Times.decYearToUnixSec( 1970 ) );
     }
 
+    public void testIsoDoy() {
+        assertEquals( Times.isoToMjd( "2023-01-23T12:34:56.789" ),
+                      Times.isoToMjd( "2023-023T12:34:56.789" ) );
+        assertEquals( Times.isoToUnixSec( "2003-03-01" ),
+                      Times.isoToUnixSec( "2003-060" ) );
+        assertEquals( Times.isoToUnixSec( "2004-03-01" ),
+                      Times.isoToUnixSec( "2004-061" ) );
+    }
+
     private static double rnd() {
         return RANDOM.nextDouble();
     }
